@@ -93,7 +93,6 @@ class Package:
         # Installation information
         self.use = 'no'
         self.installation = 'no'
-        self.installation_pdf = 'no'
         self.source_dir = None
         self.install_dir = None
         self.config_opts = ''
@@ -216,22 +215,10 @@ class Package:
         if self.cc is not None: configure = configure + ' CC=\"' + self.cc + '\"'
         if self.fc is not None: configure = configure + ' FC=\"' + self.fc + '\"'
 
-        # Install the package
+        # Install the package and clean build directory
         run_command(configure, "Configure", self.name, self.log_file)
         run_command("make", "Compile", self.name, self.log_file)
         run_command("make install", "Install", self.name, self.log_file)
-
-        # Install pdf documentation if needed
-        if self.installation_pdf == 'yes':
-            try:
-                run_command("make pdf", "Generate documentation",
-                            self.name, self.log_file)
-                run_command("make install-pdf", "Install documentation",
-                            self.name, self.log_file)
-            except:
-                pass
-
-        # Clean build directory
         run_command("make clean", "Clean", self.name, self.log_file)
 
         # End of installation
@@ -307,14 +294,13 @@ class Setup:
             Package(name="Code_Saturne",
                     description="Code_Saturne CFD tool",
                     package="code_saturne",
-                    version="2.1.0",
-                    archive="code_saturne-210.zip",
+                    version="2.1.4",
+                    archive="code_saturne-214.zip",
                     url=url_cs)
 
         p = self.packages['code_saturne']
         p.use = 'yes'
         p.installation = 'yes'
-        p.installation_pdf = 'yes'
 
         # CGNS library
 
@@ -337,8 +323,8 @@ class Setup:
             Package(name="HDF5",
                     description="Hierarchical Data Format",
                     package="hdf5",
-                    version="1.8.7",
-                    archive="hdf5-1.8.7.tar.gz",
+                    version="1.8.8",
+                    archive="hdf5-1.8.8.tar.gz",
                     url="http://www.hdfgroup.org/ftp/HDF5/current/src/%s")
 
         p = self.packages['hdf5']
@@ -363,8 +349,8 @@ class Setup:
             Package(name="MPI",
                     description="Message Passing Interface",
                     package="openmpi",
-                    version="1.4.3",
-                    archive="openmpi-1.4.3.tar.gz",
+                    version="1.4.4",
+                    archive="openmpi-1.4.4.tar.gz",
                     url="http://www.open-mpi.org/software/ompi/v1.4/downloads/%s")
 
         # Libxml2 library (official url "ftp://xmlsoft.org/libxml2/%s")
@@ -653,28 +639,6 @@ Check the setup file and some utilities presence.
                              "Please install development tools.\n\n")
             sys.exit(1)
 
-        # Looking for pdflatex for potential documentation compilation
-        ret = run_test("pdflatex")
-        if ret != 0:
-            self.packages['code_saturne'].installation_pdf = 'no'
-            sys.stderr.write("\n*** Warning: "
-                             "pdflatex utility cannot be found\n"
-                             "Code_Saturne documentation will not be "
-                             "installed\n")
-        else:
-            self.packages['code_saturne'].installation_pdf = 'yes'
-
-        # Looking for fig2dev for potential documentation compilation
-        ret = run_test("fig2dev")
-        if ret != 0:
-            self.packages['code_saturne'].installation_pdf = 'no'
-            sys.stderr.write("\n*** Warning: "
-                             "fig2dev utility cannot be found\n"
-                             "Code_Saturne documentation will not be "
-                             "installed\n")
-        else:
-            self.packages['code_saturne'].installation_pdf = 'yes'
-
         if verbose == 'yes':
             sys.stdout.write("\n")
 
