@@ -1,30 +1,25 @@
-# -*- coding: iso-8859-1 -*-
-#
+# -*- coding: utf-8 -*-
+
 #-------------------------------------------------------------------------------
+
+# This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-#     This file is part of the Code_Saturne User Interface, element of the
-#     Code_Saturne CFD tool.
+# Copyright (C) 1998-2011 EDF S.A.
 #
-#     Copyright (C) 1998-2009 EDF S.A., France
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
 #
-#     contact: saturne-support@edf.fr
-#
-#     The Code_Saturne User Interface is free software; you can redistribute it
-#     and/or modify it under the terms of the GNU General Public License
-#     as published by the Free Software Foundation; either version 2 of
-#     the License, or (at your option) any later version.
-#
-#     The Code_Saturne User Interface is distributed in the hope that it will be
-#     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-#     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-#
-#     You should have received a copy of the GNU General Public License
-#     along with the Code_Saturne Kernel; if not, write to the
-#     Free Software Foundation, Inc.,
-#     51 Franklin St, Fifth Floor,
-#     Boston, MA  02110-1301  USA
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
 #
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+# Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
 #-------------------------------------------------------------------------------
 
 """
@@ -55,12 +50,6 @@ from PyQt4.QtCore import Qt, QVariant, QString, SIGNAL, pyqtSignature
 from PyQt4.QtGui  import QDialog, QHeaderView, QStandardItemModel, QWidget
 from PyQt4.QtGui  import QAbstractItemView, QItemSelectionModel, QValidator
 
-try:
-    import mei
-    _have_mei = True
-except ImportError:
-    _have_mei = False
-
 #-------------------------------------------------------------------------------
 # Application modules import
 #-------------------------------------------------------------------------------
@@ -73,8 +62,7 @@ from Pages.Boundary                       import Boundary
 from Pages.FluidStructureInteractionAdvancedOptionsDialogForm import \
 Ui_FluidStructureInteractionAdvancedOptionsDialogForm
 
-if _have_mei:
-    from Pages.QMeiEditorView import QMeiEditorView
+from Pages.QMeiEditorView import QMeiEditorView
 
 #-------------------------------------------------------------------------------
 # log config
@@ -423,10 +411,6 @@ class FormulaCoupling(Coupling):
         # call getter to create default value if needed
         self.getBoundaryDefinedValue()
 
-        # Disable button if _have_mei is false
-        if not _have_mei:
-            self.getWidget().setEnabled(False)
-
 
     @pyqtSignature("const QString&")
     def __slotFormula(self, text):
