@@ -84,6 +84,9 @@ from LifeCycleCORBA import *
 import SALOMEDS
 import SALOMEDS_Attributes_idl
 
+import SMESH
+import salome
+
 #-------------------------------------------------------------------------------
 # Application modules
 #-------------------------------------------------------------------------------
@@ -93,14 +96,21 @@ from CFDSTUDYGUI_Commons import CaseInProcessStart, CaseInProcessEnd
 import CFDSTUDYGUI_SolverGUI
 from CFDSTUDYGUI_CommandMgr import runCommand
 
+#-------------------------------------------------------------------------------
+# For Error Message Box
+#-------------------------------------------------------------------------------
+
+#import CFDSTUDYGUI_DesktopMgr
+from PyQt4.QtGui import QMessageBox
+
 #-------------------------------------------------------------------------------
 # log config
 #-------------------------------------------------------------------------------
 
 logging.basicConfig()
 log = logging.getLogger("CFDSTUDYGUI_DataModel")
-log.setLevel(logging.DEBUG)
-#log.setLevel(logging.NOTSET)
+#log.setLevel(logging.DEBUG)
+log.setLevel(logging.NOTSET)
 
 #-------------------------------------------------------------------------------
 # Module name. Attribut "AttributeName" for the related SObject.
@@ -124,8 +134,6 @@ dict_object["Case"]          = 100003
 dict_object["CaseInProcess"] = 100004
 
 dict_object["DATAFolder"]    = 100010
-dict_object["PRETLink"]      = 100011
-dict_object["SUITELink"]     = 100012
 dict_object["DATAFile"]      = 100013
 dict_object["DRAFTFolder"]   = 100014
 dict_object["DATADRAFTFile"] = 100015
@@ -144,10 +152,7 @@ dict_object["USRSRCFile"]   = 100025
 
 dict_object["RESUFolder"]  = 100030
 dict_object["RESUFile"]    = 100031
-# VirtFolder correspond a un repertoire virtuel dans l'object browser,
-# cree pour regrouper les repertoires et fichiers
-# issus d'un runcase : correspond a la date d'execution
-dict_object["VirtFolder"]    = 100032
+dict_object["RESUSubFolder"] = 100032
 dict_object["RESSRCFolder"]  = 100033
 dict_object["RESSRCFile"]    = 100034
 dict_object["HISTFolder"]    = 100035
@@ -184,25 +189,6 @@ dict_object["UnvFile"]        = 100081
 dict_object["POSTFolder"]     = 100090
 dict_object["POSTFile"]       = 100091
 
-# LocalId attributes for PublishedIntoObjectBrowser method
-dict_object["PublishedIntoObjectBrowser"]          = 200000
-dict_object["PublishedMeshIntoObjectBrowser"]      = 200001
-dict_object["PublishedMeshGroupIntoObjectBrowser"] = 200002
-dict_object["PublishedMeshGroupFacesIntoObjectBrowser"] = 200003
-dict_object["PublishedMeshGroupCellsIntoObjectBrowser"] = 200004
-
-listPublishedId = [dict_object["PublishedIntoObjectBrowser"],
-                   dict_object["PublishedMeshIntoObjectBrowser"],
-                   dict_object["PublishedMeshGroupFacesIntoObjectBrowser"],
-                   dict_object["PublishedMeshGroupCellsIntoObjectBrowser"],
-                   dict_object["PublishedMeshGroupIntoObjectBrowser"] ]
-
-# listPublishedId is used into PublishedIntoObjectBrowser method and caracterize entries
-# PublishedIntoObjectBrowser method adds entries into Salome Object Browser.
-# These entries do not provide from an Unix cfd study directory, and are idendified into the object browser
-# by a localId Attribute from the python list listPublishedId
-
-
 #-------------------------------------------------------------------------------
 # Definition of the icon of objects to represent in the Object Browser.
 # Attribut "AttributePixMap" for the related SObject.
@@ -217,8 +203,6 @@ icon_collection[dict_object["Case"]]           = "CFDSTUDY_CASE_OBJ_ICON"
 icon_collection[dict_object["CaseInProcess"]]  = "CFDSTUDY_CASE_IN_PROC_OBJ_ICON"
 
 icon_collection[dict_object["DATAFolder"]]     = "CFDSTUDY_FOLDER_OBJ_ICON"
-icon_collection[dict_object["PRETLink"]]       = "CFDSTUDY_LINK_OBJ_ICON"
-icon_collection[dict_object["SUITELink"]]      = "CFDSTUDY_LINK_OBJ_ICON"
 icon_collection[dict_object["DATAFile"]]       = "CFDSTUDY_EDIT_DOCUMENT_OBJ_ICON"
 icon_collection[dict_object["DRAFTFolder"]]    = "CFDSTUDY_FOLDER_OBJ_ICON"
 icon_collection[dict_object["DATADRAFTFile"]]  = "CFDSTUDY_EDIT_DOCUMENT_OBJ_ICON"
@@ -236,7 +220,7 @@ icon_collection[dict_object["USRSRCFile"]]     = "CFDSTUDY_EDIT_DOCUMENT_OBJ_ICO
 
 icon_collection[dict_object["RESUFolder"]]     = "CFDSTUDY_FOLDER_OBJ_ICON"
 icon_collection[dict_object["RESUFile"]]       = "CFDSTUDY_DOCUMENT_OBJ_ICON"
-icon_collection[dict_object["VirtFolder"]]     = "CFDSTUDY_FOLDER_VIRTUAL_OBJ_ICON"
+icon_collection[dict_object["RESUSubFolder"]]  = "CFDSTUDY_FOLDER_OBJ_ICON"
 icon_collection[dict_object["RESSRCFolder"]]   = "CFDSTUDY_FOLDER_OBJ_ICON"
 icon_collection[dict_object["RESSRCFile"]]     = "CFDSTUDY_DOCUMENT_OBJ_ICON"
 icon_collection[dict_object["HISTFolder"]]     = "CFDSTUDY_FOLDER_OBJ_ICON"
@@ -273,16 +257,6 @@ icon_collection[dict_object["UnvFile"]]        = "MESH_OBJ_ICON"
 icon_collection[dict_object["POSTFolder"]]     = "CFDSTUDY_FOLDER_OBJ_ICON"
 icon_collection[dict_object["POSTFile"]]       = "CFDSTUDY_DOCUMENT_OBJ_ICON"
 
-#mark folder as linked
-icon_collection[dict_object["PRETFolder"]+1000]  = "CFDSTUDY_FOLDER_LINKED_OBJ_ICON"
-icon_collection[dict_object["SUITEFolder"]+1000] = "CFDSTUDY_FOLDER_LINKED_OBJ_ICON"
-
-icon_collection[dict_object["PublishedIntoObjectBrowser"]]          = "MESH_TREE_OBJ_ICON"
-icon_collection[dict_object["PublishedMeshIntoObjectBrowser"]]      = "MESH_TREE_OBJ_ICON"
-icon_collection[dict_object["PublishedMeshGroupIntoObjectBrowser"]] = "MESH_GROUP_TREE_OBJ_ICON"
-icon_collection[dict_object["PublishedMeshGroupFacesIntoObjectBrowser"]] = ""
-icon_collection[dict_object["PublishedMeshGroupCellsIntoObjectBrowser"]] = ""
-
 #-------------------------------------------------------------------------------
 # ObjectTR is a convenient object for traduction purpose
 #-------------------------------------------------------------------------------
@@ -349,6 +323,19 @@ def _getStudy():
     return study
 
 
+def _getlistOfOpenStudies():
+    return studyManager.GetOpenStudies()
+
+def _getStudy_Id(studyName) :
+    s=studyManager.GetStudyByName(studyName)
+    return s._get_StudyId()
+
+def _getNewBuilder():
+    study   = _getStudy()
+    builder = study.NewBuilder()
+    return builder
+
+
 def _getComponent():
     """
     Returns the component object if CFDSTUDY is active.
@@ -421,8 +408,8 @@ def _SetStudyLocation(theStudyPath, theCaseNames):
     study   = _getStudy()
     builder = study.NewBuilder()
     father  = _findOrCreateComponent()
-
     studyObject = FindStudyByPath(theStudyPath)
+    iok = True
     if studyObject == None:
         #obtain name and dir for new study
         lst = os.path.split(theStudyPath)
@@ -446,40 +433,43 @@ def _SetStudyLocation(theStudyPath, theCaseNames):
         CreateStudy = True
         if os.path.exists(theStudyPath):
             CreateStudy = False
-        _CallCreateScript(theStudyPath, CreateStudy, theCaseNames)
-        UpdateSubTree(studyObject)
+        iok = _CallCreateScript(theStudyPath, CreateStudy, theCaseNames)
+        if iok :
+            UpdateSubTree(studyObject)
     else :
 
         CreateStudy = True
         if os.path.exists(theStudyPath):
             CreateStudy = False
-        _CallCreateScript(theStudyPath, CreateStudy, theCaseNames)
+            iok = _CallCreateScript(theStudyPath, CreateStudy, theCaseNames)
         # here, if CreateStudy is True, _SetStudyLocation is used to add a case into a CFD study
         #updating Object browser : optimization : UpdateSubTree(studyObject) updates all the cases inside of de studyObject
         # here it only updates the concerned cases
-        objList = []
-        objMap  = {}
-        iter  = study.NewChildIterator(studyObject)
-        while iter.More():
-            casename = iter.Value().GetName()
-            if casename != "" :
-                objList.append(iter.Value().GetName())
-                objMap[iter.Value().GetName()]  = iter.Value()
-            iter.Next()
-        if len(theCaseNames) != 0 :
-            import string
-            CaseName_list = string.split(string.upper(theCaseNames),' ')
+        if iok :
+            objList = []
+            objMap  = {}
+            iter  = study.NewChildIterator(studyObject)
+            while iter.More():
+                casename = iter.Value().GetName()
+                if casename != "" :
+                    objList.append(iter.Value().GetName())
+                    objMap[iter.Value().GetName()]  = iter.Value()
+                iter.Next()
+            if len(theCaseNames) != 0 :
+                import string
+                CaseName_list = string.split(string.upper(theCaseNames),' ')
 
-            for casename in CaseName_list :
-                if not casename == "" and casename not in objList :
-                    caseObject  = builder.NewObject(studyObject)
-                    attr    = builder.FindOrCreateAttribute(caseObject, "AttributeLocalID")
-                    attr.SetValue(dict_object["Case"])
-                    attr = builder.FindOrCreateAttribute(caseObject, "AttributeName")
-                    attr.SetValue(casename)
-                    _SetIcon(caseObject, builder)
-                    attr = builder.FindOrCreateAttribute(caseObject, "AttributeComment")
-                    UpdateSubTree(caseObject)
+                for casename in CaseName_list :
+                    if not casename == "" and casename not in objList :
+                        caseObject  = builder.NewObject(studyObject)
+                        attr    = builder.FindOrCreateAttribute(caseObject, "AttributeLocalID")
+                        attr.SetValue(dict_object["Case"])
+                        attr = builder.FindOrCreateAttribute(caseObject, "AttributeName")
+                        attr.SetValue(casename)
+                        _SetIcon(caseObject, builder)
+                        attr = builder.FindOrCreateAttribute(caseObject, "AttributeComment")
+                        UpdateSubTree(caseObject)
+    return iok
 
 def _CallCreateScript(theStudyPath, isCreateStudy, theCaseNames):
     """
@@ -492,45 +482,49 @@ def _CallCreateScript(theStudyPath, isCreateStudy, theCaseNames):
     @type theCaseNames: C{String}
     @param theCaseNames: unix pathes of the new CFD cases to be build.
     """
-
+    mess = ""
     if isCreateStudy or theCaseNames != "":
-        scrpt, c = BinCode()
+        scrpt, c ,mess = BinCode()
+        if mess == "" :
+            curd = os.path.abspath('.')
 
-        curd = os.path.abspath('.')
+            start_dir = ""
+            if isCreateStudy:
+                fatherdir,etude = os.path.split(theStudyPath)
+                start_dir = fatherdir
+            else:
+                start_dir = theStudyPath
 
-        start_dir = ""
-        if isCreateStudy:
-            fatherdir,etude = os.path.split(theStudyPath)
-            start_dir = fatherdir
-        else:
-            start_dir = theStudyPath
+            args = [scrpt]
+            args.append('create')
 
-        args = [scrpt]
-        args.append('create')
+            if isCreateStudy:
+                if CFD_Code() == "Code_Saturne":
+                    args.append("--study")
+                elif CFD_Code() == "NEPTUNE_CFD":
+                    args.append("--study")
+                args.append(os.path.basename(theStudyPath))
+ #           else:
+ #                if CFD_Code() == "Code_Saturne":
+ #                    args.append("--case")
+ #                elif  CFD_Code() == "NEPTUNE_CFD":
+#                     args.append("--case")
 
-        if isCreateStudy:
-            if CFD_Code() == "Code_Saturne":
-                args.append("--study")
-            elif CFD_Code() == "NEPTUNE_CFD":
-                args.append("--study")
-            args.append(os.path.basename(theStudyPath))
-        else:
-            if CFD_Code() == "Code_Saturne":
-                args.append("--case")
-            elif  CFD_Code() == "NEPTUNE_CFD":
+            for i in theCaseNames.split(' '):
                 args.append("--case")
+                args.append(i)
+            if Trace():
+                print '_CreateStudy',theStudyPath,theCaseNames,'curdir',curd
+                print 'CFDSTUDYGUI_DataModel : _CallCreateScript : scrpt = ',scrpt
+                print 'CFDSTUDYGUI_DataModel : _CallCreateScript : args  = ',args
+                print 'CFDSTUDYGUI_DataModel : _CallCreateScript : start_dir = ',start_dir
+            runCommand(args, start_dir, "")
 
-        for i in theCaseNames.split(' '):
-            args.append(i)
-
-        if Trace():
-            print '_CreateStudy',theStudyPath,theCaseNames,'curdir',curd
-            print 'CFDSTUDYGUI_DataModel : _CallCreateScript : scrpt = ',scrpt
-            print 'CFDSTUDYGUI_DataModel : _CallCreateScript : args  = ',args
-            print 'CFDSTUDYGUI_DataModel : _CallCreateScript : start_dir = ',start_dir
-        runCommand(args, start_dir, "")
-
-        os.chdir(curd)
+            os.chdir(curd)
+        else :
+            QMessageBox.critical(None,
+                                "Error", mess, QMessageBox.Ok, 0)
+    return mess == ""
 
 
 def _UpdateStudy():
@@ -559,9 +553,9 @@ def UpdateSubTree(theObject=None):
         _RebuildTreeRecursively(theObject)
     else:
         _UpdateStudy()
-
+    # --- update object browser from a thread different of the main thread is not safe !
     studyId = sgPyQt.getStudyId()
-    sgPyQt.updateObjBrowser(studyId, 1)
+    sgPyQt.updateObjBrowser(studyId,1)
 
 
 def _RebuildTreeRecursively(theObject):
@@ -597,19 +591,16 @@ def _RebuildTreeRecursively(theObject):
 
     # clean the SObject, if the corresponding file or directory
     # does not exist any more in the file system
-    # (but not special virtual objects)
 
     if os.path.isfile(theObjectPath) and attr.Value() == dict_object["MEDFile"]:
         return
 
     if not os.path.isdir(theObjectPath) and not os.path.isfile(theObjectPath):
-        if not attr.Value() == dict_object["VirtFolder"]:
-            builder.RemoveObjectWithChildren(theObject)
-            return
+        builder.RemoveObjectWithChildren(theObject)
+        return
 
     # build a list of file from the file system
     dirList = _GetDirList(theObject)
-
     # build a list and a dictionary of childs SObject from the current SObject
     objList = []
     objMap  = {}
@@ -649,6 +640,7 @@ def _RebuildTreeRecursively(theObject):
                 if not dirEnd:
                     #append new object
                     if Trace(): print "1 Append new Item: ", dirName
+                    log.debug("_RebuildTreeRecursively 4: dirName = %s objName = %s" %(dirName,objName))
                     _CreateObject(theObject, builder, dirName)
                     dirIndex+=1
 
@@ -675,6 +667,7 @@ def _RebuildTreeRecursively(theObject):
                 else:
                     #append new item at the end
                     if Trace(): print "2 Append new Item: ", dirName
+                    log.debug("_RebuildTreeRecursively 5: dirName = %s objName = %s" %(dirName,objName))
                     _CreateObject(theObject, builder, dirName)
                     dirIndex+=1
 
@@ -703,12 +696,9 @@ def _RebuildTreeRecursively(theObject):
     iter  = study.NewChildIterator(theObject)
     while iter.More():
         if iter.Value().GetName():
-            # do not create tree for links and for published item
-            attr = builder.FindOrCreateAttribute(iter.Value(), "AttributeLocalID")
-            if not attr.Value() == dict_object["PRETLink"] and \
-               not attr.Value() == dict_object["SUITELink"]:
-                _RebuildTreeRecursively(iter.Value())
+            _RebuildTreeRecursively(iter.Value())
         iter.Next()
+    log.debug("_RebuildTreeRecursively -> %s END" % (theObject.GetName()))
 
 
 def _CreateObject(theFather, theBuilder, theName):
@@ -732,6 +722,16 @@ def _CreateObject(theFather, theBuilder, theName):
     attr.SetValue(theName)
     _FillObject(newChild, theFather, theBuilder)
 
+def _CreateItem(theFather,theNewName) :
+    """
+    Creates a child with name theNewName under theFather root into Object Brother
+    @type theFather: C{SObject}
+    @type theNewName : C{String}
+    """
+    log.debug("_CreateItem: NewItem = %s with Parent = %s" % (theNewName,theFather.GetName()))
+    if theNewName not in ScanChildNames(theFather,  ".*") :
+        theBuilder = _getNewBuilder()
+        _CreateObject(theFather, theBuilder, theNewName)
 
 def _FillObject(theObject, theParent, theBuilder):
     """
@@ -754,6 +754,7 @@ def _FillObject(theObject, theParent, theBuilder):
 
     # Parent is study
     if parentId == dict_object["Study"]:
+        if Trace(): print "parent is Study ", theParent.GetName()
         #check for case
         if os.path.isdir(path):
             dirList = os.listdir(path)
@@ -789,17 +790,10 @@ def _FillObject(theObject, theParent, theBuilder):
     # parent is DATA folder
     elif parentId == dict_object["DATAFolder"]:
         if os.path.isdir(path):
-            if os.path.islink(path):
-                if name == "PRE_TRAITEMENT":
-                    objectId = dict_object["PRETLink"]
-                elif name == "SUITE":
-                    objectId = dict_object["SUITELink"]
-
-            else:
-                if name == "DRAFT":
-                    objectId = dict_object["DRAFTFolder"]
-                elif name == "THCH":
-                    objectId = dict_object["THCHFolder"]
+            if name == "DRAFT":
+                objectId = dict_object["DRAFTFolder"]
+            elif name == "THCH":
+                objectId = dict_object["THCHFolder"]
         else:
             if name == "SaturneGUI" or name == "NeptuneGUI":
                 objectId = dict_object["DATALaunch"]
@@ -811,24 +805,35 @@ def _FillObject(theObject, theParent, theBuilder):
                 if os.path.isfile(path):
                     fd = os.open(path , os.O_RDONLY)
                     f = os.fdopen(fd)
-                    l = f.readline()
+                    l1 = f.readline()
+                    if l1.startswith('''<?xml version="1.0" encoding="utf-8"?><Code_Saturne_GUI''') or l1.startswith('''<?xml version="1.0" encoding="utf-8"?><NEPTUNE_CFD_GUI'''):
+                        objectId = dict_object["DATAfileXML"]
+                    elif l1.startswith('''<?xml version="1.0" encoding="utf-8"?>''') :
+                        l2 = f.readline()
+                        if l2.startswith('''<Code_Saturne_GUI''') or l2.startswith('''<NEPTUNE_CFD_GUI'''):
+                            objectId = dict_object["DATAfileXML"]
+                        else :
+                            mess = ObjectTR.tr("XML_DATA_FILE").arg(path)
+                            QMessageBox.warning(None, "File Error: ",mess)
                     f.close()
-                    if l.startswith('''<?xml version="1.0" encoding="utf-8"?><Code_Saturne_GUI'''):
-                        objectId = dict_object["DATAfileXML"]
-                    elif l.startswith('''<?xml version="1.0" encoding="utf-8"?><NEPTUNE_CFD_GUI'''):
-                        objectId = dict_object["DATAfileXML"]
+
 
     # parent is RESU folder
     elif parentId == dict_object["RESUFolder"]:
+        if Trace():
+            print "Parent is RESU folder"
+            print "Path is:", path
         if os.path.isdir(path):
-            objectId = dict_object["OtherFolder"]
-        elif os.path.isfile(path):
+            if Trace():
+                print "Object is RESU sub folder"
+            objectId = dict_object["RESUSubFolder"]
+        else:
             if re.match(".*\.med$", name):
                 objectId = dict_object["RESMEDFile"]
+            elif re.match(".*\.xml$", name):
+                objectId = dict_object["RESXMLFile"]
             else:
-                objectId = dict_object["OtherFile"]
-        else:
-            objectId = dict_object["VirtFolder"]
+                objectId = dict_object["RESUFile"]
 
     # parent is SCRIPTS folder
     elif parentId == dict_object["SCRPTFolder"]:
@@ -891,16 +896,6 @@ def _FillObject(theObject, theParent, theBuilder):
             else:
                 objectId = dict_object["MESHFile"]
 
-#    elif parentId == dict_object["PublishedMeshIntoObjectBrowser"]:
-#        if name == "Groups of Faces":
-#            objectId = dict_object["PublishedMeshGroupFacesIntoObjectBrowser"]
-#        elif name == "Groups of Cells":
-#            objectId = dict_object["PublishedMeshGroupCellsIntoObjectBrowser"]
-#
-#    elif parentId == dict_object["PublishedMeshGroupFacesIntoObjectBrowser"] \
-#          or parentId == dict_object["PublishedMeshGroupFacesIntoObjectBrowser"]:
-#            objectId = dict_object["PublishedMeshGroupIntoObjectBrowser"]
-
     # parent is POST folder
     elif parentId == dict_object["POSTFolder"]:
         if os.path.isdir(path):
@@ -964,27 +959,28 @@ def _FillObject(theObject, theParent, theBuilder):
             elif re.match(".*\.h$", name) or re.match(".*\.hpp$", name) or re.match(".*\.hxx$", name):
                 objectId = dict_object["RESSRCFile"]
 
-    # parent is VIRTUAL folder
-    elif parentId == dict_object["VirtFolder"]:
-        #needs for update path
-        path = os.path.join(_GetPath(theParent.GetFather()), name) + "." + str(theParent.GetName())
+    # parent is RESULT sub folder
+    elif parentId == dict_object["RESUSubFolder"]:
+        if Trace():
+            print "Parent is RESU folder or subfolder"
+            print "Path is:", path
         if os.path.isdir(path):
-            #folder
-            if name == "SRC":
+            if name == "src":
                 objectId = dict_object["RESSRCFolder"]
-            elif name == "HIST":
+            elif name == "monitoring":
                 objectId = dict_object["HISTFolder"]
-            elif name == "PRE_TRAITEMENT":
-                objectId = dict_object["PRETFolder"]
-            elif name == "SUITE":
+            elif name == "checkpoint":
                 objectId = dict_object["SUITEFolder"]
-            elif name == "RES_USER":
-                objectId = dict_object["RESUSERFolder"]
-            else:
-                objectId = dict_object["OtherFolder"]
-        elif os.path.isfile(path):
+            elif name == "mesh_input":
+                objectId = dict_object["PRETFolder"]
+            if Trace():
+                print "Object is RESU sub folder"
+            objectId = dict_object["RESUSubFolder"]
+        else:
             if re.match(".*\.med$", name):
                 objectId = dict_object["RESMEDFile"]
+            elif re.match(".*\.dat$", name) or re.match(".*\.csv$", name):
+                objectId = dict_object["HISTFile"]
             elif re.match(".*\.xml$", name):
                 objectId = dict_object["RESXMLFile"]
             else:
@@ -1026,7 +1022,7 @@ def _FillObject(theObject, theParent, theBuilder):
     # parent is HIST folder
     elif parentId == dict_object["HISTFolder"]:
         if os.path.isfile(path):
-            if re.match(".*\.dat$", name):
+            if re.match(".*\.dat$", name) or re.match(".*\.csv$", name):
                 objectId = dict_object["HISTFile"]
         elif os.path.isdir(path):
             objectId = dict_object["OtherFolder"]
@@ -1034,8 +1030,7 @@ def _FillObject(theObject, theParent, theBuilder):
     # parent is RES_USER folder
     elif parentId == dict_object["RESUSERFolder"]:
         if os.path.isfile(path):
-            if re.match(".*\.dat$", name) or re.match(".*\.tab$", name) or \
-               re.match(".*\.xls$", name) or re.match(".*\.txt$", name):
+            if re.match(".*\.dat$", name) or re.match(".*\.csv$", name):
                 objectId = dict_object["HISTFile"]
         elif os.path.isdir(path):
             objectId = dict_object["OtherFolder"]
@@ -1046,18 +1041,22 @@ def _FillObject(theObject, theParent, theBuilder):
            re.match(".*\.for$", name) or \
            re.match(".*\.FOR$", name):
             if _DetectUSERSObject(theObject) == True:
+                if Trace(): print "******************************", path
                 objectId = _DetectSRCObject(theParent)
         elif re.match(".*\.c$", name):
             if _DetectUSERSObject(theObject) == True:
+                if Trace(): print "******************************", path
                 objectId = _DetectSRCObject(theParent)
         elif re.match(".*\.cpp$", name) or \
            re.match(".*\.cxx$", name):
             if _DetectUSERSObject(theObject) == True:
+                if Trace(): print "******************************", path
                 objectId = _DetectSRCObject(theParent)
         elif re.match(".*\.h$", name) or \
            re.match(".*\.hxx$", name) or \
            re.match(".*\.hpp$", name):
             if _DetectUSERSObject(theObject) == True:
+                if Trace(): print "******************************", path
                 objectId = _DetectSRCObject(theParent)
 
     if objectId == dict_object["OtherFile"]:
@@ -1096,32 +1095,7 @@ def _SetIcon(theObject, theBuilder):
     id = int(attr.Value())
     if icon_collection[id] == "":
         return
-
     attr = theBuilder.FindOrCreateAttribute(theObject, "AttributePixMap")
-
-    if id == dict_object["PRETFolder"] or id == dict_object["SUITEFolder"]:
-        #check for existing link
-        case = GetCase(theObject)
-        if not case == None:
-            study = _getStudy()
-            iter  = study.NewChildIterator(case)
-            while iter.More():
-                if iter.Value().GetName() == "DATA":
-                    newpath = os.path.join(_GetPath(iter.Value()), theObject.GetName())
-                    if Trace():
-                        print "check for: ", newpath
-                        print "source: ",  os.path.normpath(_GetPath(theObject))
-                        print "exists: ",  os.path.exists(newpath)
-                        print "islink: ",  os.path.islink(newpath)
-                        print "is same: ", os.path.realpath(newpath)
-                    if os.path.exists(newpath) and \
-                       os.path.islink(newpath) and \
-                       os.path.samefile(os.path.realpath(newpath), _GetPath(theObject)):
-                        #offset for special icons
-                        id += 1000
-                    break
-                iter.Next()
-
     attr.SetPixMap(str(ObjectTR.tr(icon_collection[id]).toLatin1()))
     #check path for link and create new attribute
     if id != dict_object["Case"]:
@@ -1163,10 +1137,7 @@ def _GetPath(theObject):
 
     father = theObject.GetFather()
     attr = builder.FindOrCreateAttribute(father, "AttributeLocalID")
-    if attr.Value() == dict_object["VirtFolder"]:
-        path = os.path.join(_GetPath(father.GetFather()), path) + "." + str(father.GetName())
-    else:
-        path = os.path.join(_GetPath(father), path)
+    path = os.path.join(_GetPath(father), path)
 
     return path
 
@@ -1186,61 +1157,13 @@ def _GetDirList(theObject):
     path = _GetPath(theObject)
     attr = builder.FindOrCreateAttribute(theObject, "AttributeLocalID")
     lst = []
-
-    if attr.Value() == dict_object["VirtFolder"]:
-        name = theObject.GetName()
-        path = _GetPath(theObject.GetFather())
-        if Trace(): print "Path for virt scan: ", path
-        temp = os.listdir(path)
-        for s in temp:
-            if re.match(".*\." + name + "$", s):
-                l = s.split(".")
-                l.remove(name)
-                lst.append(string.join(l, "."))
-
-    elif attr.Value() == dict_object["RESUFolder"]:
-        temp = os.listdir(path)
-        for s in temp:
-            if re.match(".*\.[0-9]+$", s):
-                l = s.split(".")
-                vf = l[len(l)-1]
-                if lst.count(vf) == 0:
-                    lst.append(vf)
-            else:
-                lst.append(s)
-
-    elif os.path.isdir(path):
+    if os.path.isdir(path):
         lst = os.listdir(path)
 
     lst.sort()
     return lst
 
 
-def _DetectVirtualFolder(thePath):
-    """
-    Returns the list of the time extension of the results files and folders.
-
-    @type thePath: C{String}
-    @param thePath: unix path of a folder.
-    @return: list of time extension.
-    @rtype: C{List} of C{String}
-    """
-    temp = os.listdir(thePath)
-    lst = []
-    for s in temp:
-        if re.match(".*\.[0-9]+$", s):
-            l = s.split(".")
-            a = ""
-            i = 0
-            while i < len(l) - 2:
-                a += l[i] + "."
-                i+=1
-            a += l[len(l)-2]
-            lst.append(a)
-
-    return lst
-
-
 def _DetectUSERSObject(theObject):
     """
     Search if the branch I{theObject} represents the USERS folder.
@@ -1354,17 +1277,11 @@ def GetStudyByObj(theObject):
     @return: study to which belongs the I{theObject}.
     @rtype: C{SObject}
     """
-    if Trace(): print "TheObject", theObject
-
     if theObject == None:
         return None
 
     study   = _getStudy()
-    if Trace(): print "get study:", study
-
     builder = study.NewBuilder()
-    if Trace(): print "builder:", builder
-
     cur = theObject
 
     while cur:
@@ -1778,6 +1695,13 @@ def checkPathUnderObject(theObject, thePath):
 
     return aParent
 
+def getSObject(theParent,Name) :
+    Sobjlist = ScanChildren(theParent,  ".*")
+    SObj = None
+    for i in Sobjlist :
+        if i.GetName() == Name :
+            SObj = i
+    return SObj
 
 def findMaxDeepObject(thePath):
     """
@@ -1814,21 +1738,83 @@ def findMaxDeepObject(thePath):
     return parent
 
 
-def publishInStudySalome(SO_father, objName, idElem):
+#def publishInStudySalome(SO_father, objName, idElem):
+    #"""
+    #Publish objName into Object Browser under SO_father with the AttributeLocalID idElem
+    #listPublishedId is used into PublishedIntoObjectBrowser method and caracterize entries
+    #PublishedIntoObjectBrowser method adds entries into Salome Object Browser.
+    #These entries do not provide from an Unix cfd study directory, and are idendified into the object browser
+    #by a localId Attribute from the python list listPublishedId
+    #"""
+    #study = _getStudy()
+    #builder = study.NewBuilder()
+    #studyObject = builder.NewObject(SO_father)
+    #attr = builder.FindOrCreateAttribute(studyObject, "AttributeName")
+    #attr.SetValue(objName)
+    #attr = builder.FindOrCreateAttribute(studyObject, "AttributeLocalID")
+    #attr.SetValue(idElem)
+    #_SetIcon(studyObject, builder)
+    #log.debug("publishInStudySalome: %s" % ScanChildNames(SO_father,  ".*"))
+    #return studyObject
+
+
+def getOrLoadObject(item):
     """
-    Publish objName into Object Browser under SO_father with the AttributeLocalID idElem
-    listPublishedId is used into PublishedIntoObjectBrowser method and caracterize entries
-    PublishedIntoObjectBrowser method adds entries into Salome Object Browser.
-    These entries do not provide from an Unix cfd study directory, and are idendified into the object browser
-    by a localId Attribute from the python list listPublishedId
+    Get the CORBA object associated with the SObject `item`, eventually by
+    first loading it with the corresponding engine.
     """
-    study = _getStudy()
-    builder = study.NewBuilder()
-    studyObject = builder.NewObject(SO_father)
-    attr = builder.FindOrCreateAttribute(studyObject, "AttributeName")
-    attr.SetValue(objName)
-    attr = builder.FindOrCreateAttribute(studyObject, "AttributeLocalID")
-    attr.SetValue(idElem)
-    _SetIcon(studyObject, builder)
-    log.debug("publishInStudySalome: %s" % ScanChildNames(SO_father,  ".*"))
-    return studyObject
+    object = item.GetObject()
+    if object is None: # the engine has not been loaded yet
+        sComponent = item.GetFatherComponent()
+        #self.loadComponentEngine(sComponent)
+        study   = _getStudy()
+        builder = study.NewBuilder()
+        engine = _getEngine()
+        if engine is None:
+            print "Cannot load component ", __MODULE_NAME__
+        object = item.GetObject()
+    return object
+
+def getMeshFromMesh(meshSobjItem) :
+    """
+    return: The SALOMEDS._objref_SObject instance of the mesh, if the meshSobjItem is a sobj of a mesh, None if not
+    """
+    meshItem = None
+    obj = getOrLoadObject(meshSobjItem)
+    if obj is not None:
+        mesh = obj._narrow(SMESH.SMESH_Mesh)
+
+        if mesh is not None:
+            meshItem = salome.ObjectToSObject(mesh)
+
+    return meshItem
+
+def SetAutoColor (meshSobjItem) :
+    obj = getOrLoadObject(meshSobjItem)
+    if obj is not None:
+        mesh = obj._narrow(SMESH.SMESH_Mesh)
+        if mesh is not None:
+            mesh.SetAutoColor(1)
+
+def getMeshFromGroup(meshGroupItem):
+    """
+    Get the mesh item owning the mesh group `meshGroupItem`.
+
+    :type   meshGroupItem: SObject
+    :param  meshGroupItem: Mesh group belonging to the searched mesh.
+
+    :return: The SALOMEDS._objref_SObject instance corresponding to the mesh group or None
+             and SMESH._objref_SMESH_Group instance  or None if it was not
+             found.
+    """
+    group = None
+    meshItem = None
+    obj = getOrLoadObject(meshGroupItem)
+    #obj = self.editor.getOrLoadObject(meshGroupItem) # version 515
+
+    if obj is not None:
+        group = obj._narrow(SMESH.SMESH_GroupBase)
+        if group is not None: # The type of the object is ok
+            meshObj = group.GetMesh()
+            meshItem = salome.ObjectToSObject(meshObj)
+    return meshItem,group
