@@ -1,34 +1,29 @@
-/*============================================================================
- *
- *     This file is part of the Code_Saturne Kernel, element of the
- *     Code_Saturne CFD tool.
- *
- *     Copyright (C) 1998-2009 EDF S.A., France
- *
- *     contact: saturne-support@edf.fr
- *
- *     The Code_Saturne Kernel is free software; you can redistribute it
- *     and/or modify it under the terms of the GNU General Public License
- *     as published by the Free Software Foundation; either version 2 of
- *     the License, or (at your option) any later version.
- *
- *     The Code_Saturne Kernel is distributed in the hope that it will be
- *     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
- *     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with the Code_Saturne Kernel; if not, write to the
- *     Free Software Foundation, Inc.,
- *     51 Franklin St, Fifth Floor,
- *     Boston, MA  02110-1301  USA
- *
- *============================================================================*/
-
 /*============================================================================
  * SYRTHES 3 coupling
  *============================================================================*/
 
+/*
+  This file is part of Code_Saturne, a general-purpose CFD tool.
+
+  Copyright (C) 1998-2011 EDF S.A.
+
+  This program is free software; you can redistribute it and/or modify it under
+  the terms of the GNU General Public License as published by the Free Software
+  Foundation; either version 2 of the License, or (at your option) any later
+  version.
+
+  This program is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+  details.
+
+  You should have received a copy of the GNU General Public License along with
+  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+  Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
+/*----------------------------------------------------------------------------*/
+
 #if defined(HAVE_CONFIG_H)
 #include "cs_config.h"
 #endif
@@ -114,7 +109,7 @@ struct _cs_syr3_coupling_t {
   int             dim;              /* Coupled mesh dimension */
   int             ref_axis;         /* Selected axis for edge extraction */
 
-  int             syr_num;          /* SYRTHES number */
+  char           *syr_name;         /* SYRTHES instance name */
 
   /* Boundary faces parameters of coupled mesh */
 
@@ -129,6 +124,7 @@ struct _cs_syr3_coupling_t {
 
   /* Saved arrays for post processing (float for reduced memory use) */
 
+  int             visualization;    /* Visualization output level */
   int             post_mesh_id;     /* 0 if post-processing is not active,
                                        mesh_id if post-processing is active */
   float          *wall_temp;        /* Wall temperature (received) */
@@ -153,13 +149,13 @@ struct _cs_syr3_coupling_t {
  *  Global variables
  *============================================================================*/
 
-static int                   cs_glob_syr_n_couplings = 0;
-static cs_syr3_coupling_t  **cs_glob_syr_coupling_array = NULL;
+static int                   cs_glob_syr3_n_couplings = 0;
+static cs_syr3_coupling_t  **cs_glob_syr3_couplings = NULL;
 
 /* Start and end (negative) numbers associated with
    dedicated post processing meshes */
 
-static int  cs_glob_syr_post_maillage_ext[2] = {0, 1};
+static int  cs_glob_syr3_post_maillage_ext[2] = {0, 1};
 
 
 /*============================================================================
@@ -230,6 +226,7 @@ _define_coupled_mesh(char                *coupled_mesh_name,
   coupled_mesh
     = cs_mesh_connect_faces_to_nodal(cs_glob_mesh,
                                      coupled_mesh_name,
+                                     false,
                                      0,
                                      syr_coupling->n_faces,
                                      NULL,
@@ -847,6 +844,89 @@ _cs_syr3_coupling_post_function(int        coupling_id,
 
 }
 
+/*----------------------------------------------------------------------------
+ * Initialize post-processing of a Syrthes coupling
+ *
+ * parameters:
+ *   syr_coupling <-- SYRTHES coupling structure
+ *----------------------------------------------------------------------------*/
+
+static void
+_post_init(cs_syr3_coupling_t  *syr_coupling)
+{
+  int  dim_shift = 0;
+  int coupling_id = -1;
+
+  const int writer_id = -1;
+  const int writer_ids[] = {writer_id};
+
+  cs_int_t  n_vertices = 0;
+  cs_int_t  mesh_id = cs_post_get_free_mesh_id();
+
+  assert(syr_coupling != NULL);
+
+  /* Determine coupling id */
+
+  for (coupling_id = 0;
+       (   coupling_id < cs_glob_syr3_n_couplings
+        && cs_glob_syr3_couplings[coupling_id] != syr_coupling);
+       coupling_id++);
+
+  /* Exit silently if associated writer is not available */
+
+  if (cs_post_writer_exists(writer_id) != true)
+    return;
+
+  /* Initialize post processing flag, and free previous arrays in
+     case this function is called more than once */
+
+  syr_coupling->post_mesh_id = mesh_id;
+
+  if (syr_coupling->wall_temp != NULL)
+    BFT_FREE(syr_coupling->wall_temp);
+
+  if (syr_coupling->flux != NULL)
+    BFT_FREE(syr_coupling->flux);
+
+  /* Get number of coupled vertices */
+
+  n_vertices = fvm_nodal_get_n_entities(syr_coupling->coupled_mesh, 0);
+
+  /* Allocate arrays */
+
+  if (n_vertices > 0) {
+    BFT_MALLOC(syr_coupling->wall_temp, n_vertices, float);
+    BFT_MALLOC(syr_coupling->flux, n_vertices, float);
+  }
+  syr_coupling->tfluid_tmp = NULL;
+
+  /* Associate external mesh description with post processing subsystem */
+
+  if (syr_coupling->dim == 2)
+    dim_shift = 1;
+
+  cs_post_define_existing_mesh(mesh_id,
+                               syr_coupling->coupled_mesh,
+                               dim_shift,
+                               false,
+                               false,
+                               1,
+                               writer_ids);
+
+  /* Register post processing function */
+
+  cs_post_add_time_dep_var(_cs_syr3_coupling_post_function,
+                           coupling_id);
+
+  /* Update start and end (negative) numbers associated with
+     dedicated post processing meshes */
+
+  if (cs_glob_syr3_post_maillage_ext[0] == 0)
+    cs_glob_syr3_post_maillage_ext[0] = mesh_id;
+
+  cs_glob_syr3_post_maillage_ext[1] = mesh_id;
+}
+
 /*----------------------------------------------------------------------------
  * Dump of SYRTHES coupling structure
  *
@@ -867,8 +947,12 @@ _dump_syr_coupling(cs_syr3_coupling_t  *syr_coupling)
              "SYRTHES 3 coupling structure dump\n"
              "---------------------------------\n\n");
 
-  bft_printf("\nSYRTHES coupling number: %d\n",
-             syr_coupling->syr_num);
+  bft_printf("\nSYRTHES coupling name: %s\n\n"
+             "echo_comm: %d\n"
+             "visualization: %d\n",
+             syr_coupling->syr_name,
+             syr_coupling->comm_echo,
+             syr_coupling->visualization);
 
   /* Print selection criteria */
 
@@ -928,7 +1012,7 @@ _dump_syr_coupling(cs_syr3_coupling_t  *syr_coupling)
 int
 cs_syr3_coupling_n_couplings(void)
 {
-  return cs_glob_syr_n_couplings;
+  return cs_glob_syr3_n_couplings;
 }
 
 /*----------------------------------------------------------------------------
@@ -947,8 +1031,8 @@ cs_syr3_coupling_by_id(int coupling_id)
   cs_syr3_coupling_t  *retval = NULL;
 
   if (   coupling_id > -1
-      && coupling_id < cs_glob_syr_n_couplings)
-    retval = cs_glob_syr_coupling_array[coupling_id];
+      && coupling_id < cs_glob_syr3_n_couplings)
+    retval = cs_glob_syr3_couplings[coupling_id];
 
   return retval;
 }
@@ -1058,30 +1142,40 @@ cs_syr3_coupling_get_face_list(const cs_syr3_coupling_t  *syr_coupling,
  *   dim                <-- spatial mesh dimension
  *   ref_axis           <-- reference axis
  *   face_sel_criterion <-- criterion for selection of boundary faces
- *   syr_num            <-- SYRTHES number
+ *   syr_name           <-- SYRTHES application name
  *   syr_proc_rank      <-- SYRTHES process rank for MPI
  *   comm_type          <-- communicator type
  *   verbosity          <-- verbosity level
+ *   visualization      <-- visualization output level
  *----------------------------------------------------------------------------*/
 
 void
 cs_syr3_coupling_add(int                 dim,
                      int                 ref_axis,
                      const char         *face_sel_criterion,
-                     int                 syr_num,
+                     const char         *syr_name,
                      int                 syr_proc_rank,
                      cs_syr3_comm_type_t comm_type,
-                     int                 verbosity)
+                     int                 verbosity,
+                     int                 visualization)
 {
   cs_syr3_coupling_t *syr_coupling = NULL;
 
   /* Allocate _cs_syr3_coupling_t structure */
 
-  BFT_REALLOC(cs_glob_syr_coupling_array,
-              cs_glob_syr_n_couplings + 1, cs_syr3_coupling_t*);
+  BFT_REALLOC(cs_glob_syr3_couplings,
+              cs_glob_syr3_n_couplings + 1, cs_syr3_coupling_t*);
   BFT_MALLOC(syr_coupling, 1, cs_syr3_coupling_t);
 
-  syr_coupling->syr_num = syr_num;
+  syr_coupling->syr_name = NULL;
+  if (syr_name != NULL) {
+    BFT_MALLOC(syr_coupling->syr_name, strlen(syr_name) + 1, char);
+    strcpy(syr_coupling->syr_name, syr_name);
+  }
+  else {
+    BFT_MALLOC(syr_coupling->syr_name, 1, char);
+    syr_coupling->syr_name[0] = '\0';
+  }
 
   syr_coupling->dim = dim;
   syr_coupling->ref_axis = ref_axis;
@@ -1107,6 +1201,7 @@ cs_syr3_coupling_add(int                 dim,
 
   /* Post processing */
 
+  syr_coupling->visualization = visualization;
   syr_coupling->post_mesh_id = 0;
   syr_coupling->wall_temp = NULL;
   syr_coupling->flux = NULL;
@@ -1121,8 +1216,8 @@ cs_syr3_coupling_add(int                 dim,
   syr_coupling->syr_proc_rank = syr_proc_rank;
 #endif
 
-  cs_glob_syr_coupling_array[cs_glob_syr_n_couplings] = syr_coupling;
-  cs_glob_syr_n_couplings++;
+  cs_glob_syr3_couplings[cs_glob_syr3_n_couplings] = syr_coupling;
+  cs_glob_syr3_n_couplings++;
 }
 
 /*----------------------------------------------------------------------------
@@ -1150,8 +1245,8 @@ cs_syr3_coupling_init_comm(cs_syr3_coupling_t  *syr_coupling,
                               syr_coupling->comm_echo);
 
   if (syr_coupling->comm_echo >= 0) {
-    for (i_coupl = 0 ; i_coupl < cs_glob_syr_n_couplings; i_coupl++)
-      _dump_syr_coupling(cs_glob_syr_coupling_array[i_coupl]);
+    for (i_coupl = 0 ; i_coupl < cs_glob_syr3_n_couplings; i_coupl++)
+      _dump_syr_coupling(cs_glob_syr3_couplings[i_coupl]);
   }
 }
 
@@ -1165,12 +1260,12 @@ cs_syr3_coupling_all_destroy(void)
   cs_int_t i_coupl;
   cs_syr3_coupling_t *syr_coupling = NULL;
 
-  if (cs_glob_syr_n_couplings == 0)
+  if (cs_glob_syr3_n_couplings == 0)
     return;
 
-  for (i_coupl = 0; i_coupl < cs_glob_syr_n_couplings; i_coupl++) {
+  for (i_coupl = 0; i_coupl < cs_glob_syr3_n_couplings; i_coupl++) {
 
-    syr_coupling = cs_glob_syr_coupling_array[i_coupl];
+    syr_coupling = cs_glob_syr3_couplings[i_coupl];
 
     /* Sending "End Of File" message */
 
@@ -1213,12 +1308,14 @@ cs_syr3_coupling_all_destroy(void)
       cs_syr3_comm_finalize_socket();
 #endif
 
+    BFT_FREE(syr_coupling->syr_name);
+
     BFT_FREE(syr_coupling);
 
-  } /* End of loop on cs_glob_syr_coupling_array */
+  } /* End of loop on cs_glob_syr3_couplings */
 
-  cs_glob_syr_n_couplings = 0;
-  BFT_FREE(cs_glob_syr_coupling_array);
+  cs_glob_syr3_n_couplings = 0;
+  BFT_FREE(cs_glob_syr3_couplings);
 
   bft_printf(_("\nStructures associated with SYRTHES 3 coupling freed.\n"));
   bft_printf_flush();
@@ -1251,23 +1348,22 @@ cs_syr3_coupling_init_mesh(cs_syr3_coupling_t  *syr_coupling)
 
   if (comm_echo > 0) {
     bft_printf(_("\n ** Processing the mesh for SYRTHES coupling "
-                 "\"%d\"\n\n"),
-                 syr_coupling->syr_num);
+                 "\"%s\"\n\n"),
+                 syr_coupling->syr_name);
     bft_printf_flush();
   }
 
   /* Define coupled mesh name */
 
-  length = strlen("SYRTHES_faces_") + 1 + 1;
+  length = strlen("SYRTHES  faces") + strlen(syr_coupling->syr_name) + 1;
   BFT_MALLOC(coupled_mesh_name, length + 1, char);
-  sprintf(coupled_mesh_name, "SYRTHES_faces_%d", syr_coupling->syr_num);
+  sprintf(coupled_mesh_name, "SYRTHES %s faces", syr_coupling->syr_name);
 
   /* Define coupled mesh */
 
   coupled_mesh = _define_coupled_mesh(coupled_mesh_name,
                                       syr_coupling);
 
-
   n_g_vertices = fvm_nodal_get_n_g_vertices(coupled_mesh);
 
   if (n_g_vertices == 0)
@@ -1402,9 +1498,9 @@ cs_syr3_coupling_init_mesh(cs_syr3_coupling_t  *syr_coupling)
   if (comm_echo >= 0) {
 
     if (elt_dim == 2)
-      bft_printf(_("\nExtracted mesh built of %d triangles"),n_elts);
+      bft_printf(_("\nExtracted mesh built of %d triangles"), n_elts);
     else if (elt_dim == 1)
-      bft_printf(_("\nExtracted mesh built of %d edges"),n_elts);
+      bft_printf(_("\nExtracted mesh built of %d edges"), n_elts);
     else
       assert(elt_dim == 2 || elt_dim == 1);
 
@@ -1429,6 +1525,10 @@ cs_syr3_coupling_init_mesh(cs_syr3_coupling_t  *syr_coupling)
   if (coords != NULL)
     BFT_FREE(coords);
 
+  /* Initialize post-processing */
+
+  if (syr_coupling->visualization > 0)
+    _post_init(syr_coupling);
 }
 
 /*----------------------------------------------------------------------------
@@ -1445,7 +1545,8 @@ cs_syr3_coupling_vtx_to_elt(const cs_syr3_coupling_t  *syr_coupling,
                             const cs_real_t           *vtx_values,
                             cs_real_t                 *elt_values)
 {
-  cs_int_t n_elts, stride;
+  cs_int_t n_elts;
+  cs_int_t stride = 1;
 
   cs_int_t  *parent_num = NULL;
   cs_int_t  *connect = NULL;
@@ -1532,7 +1633,8 @@ cs_syr3_coupling_elt_to_vtx(const cs_syr3_coupling_t  *syr_coupling,
                             fvm_lnum_t                 n_vertices,
                             cs_real_t                 *vtx_values)
 {
-  cs_int_t n_elts, stride;
+  cs_int_t n_elts;
+  cs_int_t stride = 1;
 
   cs_int_t  *parent_num = NULL;
   cs_int_t  *connect = NULL;
@@ -1602,80 +1704,6 @@ cs_syr3_coupling_elt_to_vtx(const cs_syr3_coupling_t  *syr_coupling,
 
 }
 
-/*----------------------------------------------------------------------------
- * Initialize post-processing of a Syrthes coupling
- *
- * parameters:
- *   coupling_id <--  Id of SYRTHES coupling
- *   writer_id   <--  Id of associated writer
- *----------------------------------------------------------------------------*/
-
-void
-cs_syr3_coupling_post_init(int       coupling_id,
-                           cs_int_t  writer_id)
-{
-  int  dim_shift = 0;
-  cs_int_t  n_vertices = 0;
-  cs_int_t  mesh_id = cs_post_get_free_mesh_id();
-
-  cs_syr3_coupling_t  *syr_coupling = cs_syr3_coupling_by_id(coupling_id);
-
-  assert(syr_coupling != NULL);
-
-  /* Exit silently if associated writer is not available */
-
-  if (cs_post_writer_exists(writer_id) != true)
-    return;
-
-  /* Initialize post processing flag, and free previous arrays in
-     case this function is called more than once */
-
-  syr_coupling->post_mesh_id = mesh_id;
-
-  if (syr_coupling->wall_temp != NULL)
-    BFT_FREE(syr_coupling->wall_temp);
-
-  if (syr_coupling->flux != NULL)
-    BFT_FREE(syr_coupling->flux);
-
-  /* Get number of coupled vertices */
-
-  n_vertices = fvm_nodal_get_n_entities(syr_coupling->coupled_mesh, 0);
-
-  /* Allocate arrays */
-
-  if (n_vertices > 0) {
-    BFT_MALLOC(syr_coupling->wall_temp, n_vertices, float);
-    BFT_MALLOC(syr_coupling->flux, n_vertices, float);
-  }
-  syr_coupling->tfluid_tmp = NULL;
-
-  /* Associate external mesh description with post processing subsystem */
-
-  if (syr_coupling->dim == 2)
-    dim_shift = 1;
-
-  cs_post_add_existing_mesh(mesh_id,
-                            syr_coupling->coupled_mesh,
-                            dim_shift,
-                            false);
-
-  cs_post_associate(mesh_id, writer_id);
-
-  /* Register post processing function */
-
-  cs_post_add_time_dep_var(_cs_syr3_coupling_post_function,
-                           coupling_id);
-
-  /* Update start and end (negative) numbers associated with
-     dedicated post processing meshes */
-
-  if (cs_glob_syr_post_maillage_ext[0] == 0)
-    cs_glob_syr_post_maillage_ext[0] = mesh_id;
-
-  cs_glob_syr_post_maillage_ext[1] = mesh_id;
-}
-
 /*----------------------------------------------------------------------------
  * Update post-processing variables of a SYRTHES coupling
  *
