@@ -1,27 +1,22 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
@@ -49,31 +44,31 @@ subroutine cpini1
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use dimens
+use numvar
+use optcal
+use cstphy
+use entsor
+use cstnum
+use ppppar
+use ppthch
+use coincl
+use cpincl
+use ppincl
+use ihmpre
+use ppcpfu
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "dimens.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "entsor.h"
-include "cstnum.h"
-include "ppppar.h"
-include "ppthch.h"
-include "coincl.h"
-include "cpincl.h"
-include "ppincl.h"
-include "ihmpre.h"
-include "ppcpfu.h"
-
-!===============================================================================
-
 integer          ipp , icla , ii , jj , iok
-integer          icha , isc , is, iphas
+integer          icha , isc , is
 double precision wmolme
 
 !===============================================================================
@@ -82,13 +77,11 @@ double precision wmolme
 !===============================================================================
 !     L'utilisateur ne doit pas y avoir touche.
 
-do iphas = 1, nphas
-  if(iscalt(iphas).ne.-1) then
-    write(nfecra,1000)iphas,iscalt(iphas)
-    call csexit (1)
-    !==========
-  endif
-enddo
+if(iscalt.ne.-1) then
+  write(nfecra,1000)iscalt
+  call csexit (1)
+  !==========
+endif
 do ii = 1, nscapp
   if(iscsth(iscapp(ii)).ne.-10) then
     write(nfecra,1001)ii,iscapp(ii),iscapp(ii),iscsth(iscapp(ii))
@@ -188,8 +181,7 @@ enddo
 
 ! ---- On resout en enthalpie avec un CP constant (Cf. cpvarp)
 
-iphas = iphsca(ihm)
-iscalt(iphas) = ihm
+iscalt = ihm
 iscsth(ihm) = 2
 
 ! --> Donnees physiques ou numeriques propres aux scalaires CP
@@ -203,7 +195,7 @@ do isc = 1, nscapp
 !        En combustion on considere que la viscosite turbulente domine
 !        ON S'INTERDIT DONC LE CALCUL DES FLAMMES LAMINAIRES AVEC Le =/= 1
 
-    visls0(jj) = viscl0(iphsca(jj))
+    visls0(jj) = viscl0
 
   endif
 
@@ -556,7 +548,7 @@ wmolme = ( wmole(io2) *oxyo2(1) +wmole(in2) *oxyn2(1)             &
           +wmole(ih2o)*oxyh2o(1)+wmole(ico2)*oxyco2(1))           &
         /(oxyo2(1)+oxyn2(1)+oxyh2o(1)+oxyco2(1))
 
-ro0(iphas) = p0(iphas)*wmolme / (rr*t0(iphas))
+ro0 = p0*wmolme / (rr*t0)
 
 ! ---- Initialisation pour la masse volumique du coke
 
@@ -580,8 +572,8 @@ srrom = -grand
 diftl0 =-grand
 
 ! ---> Masse volumique variable et viscosite constante (pour les suites)
-irovar(iphas) = 1
-ivivar(iphas) = 0
+irovar = 1
+ivivar = 0
 
 !===============================================================================
 ! 4. ON REDONNE LA MAIN A L'UTLISATEUR
@@ -630,7 +622,7 @@ endif
 '@                                                            ',/,&
 '@  L''utilisateur ne doit pas la renseigner dans usini1, or  ',/,&
 '@    elle a ete affectee comme suit :                        ',/,&
-'@    ISCALT(',I10   ,') = ',I10                               ,/,&
+'@    ISCALT = ',I10                                           ,/,&
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
 '@                                                            ',/,&
