@@ -1,49 +1,32 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine cpphyv &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse , nphmx  ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr , ibrom  , izfppp ,          &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+ ( nvar   , nscal  ,                                              &
+   ibrom  , izfppp ,                                              &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  ,                                              &
-   f3max  ,                                                       &
-   w1     , w2     , w3     , w4     ,                            &
-   w5     , w6     , w7     , w8     ,                            &
-   w9     , w10    ,                                              &
-   rdevel , rtuser , ra     )
+   coefa  , coefb  )
 
 !===============================================================================
 ! FONCTION :
@@ -63,10 +46,10 @@ subroutine cpphyv &
 !  (une routine specifique est dediee a cela : usvist)
 
 
-!  Il FAUT AVOIR PRECISE ICP(IPHAS) = 1
+!  Il FAUT AVOIR PRECISE ICP = 1
 !     ==================
 !    dans usini1 si on souhaite imposer une chaleur specifique
-!    CP variable pour la phase IPHAS (sinon: ecrasement memoire).
+!    CP variable (sinon: ecrasement memoire).
 
 
 !  Il FAUT AVOIR PRECISE IVISLS(Numero de scalaire) = 1
@@ -85,8 +68,8 @@ subroutine cpphyv &
 !    Ainsi, AU PREMIER PAS DE TEMPS (calcul non suite), les seules
 !    grandeurs initialisees avant appel sont celles donnees
 !      - dans usini1 :
-!             . la masse volumique (initialisee a RO0(IPHAS))
-!             . la viscosite       (initialisee a VISCL0(IPHAS))
+!             . la masse volumique (initialisee a RO0)
+!             . la viscosite       (initialisee a VISCL0)
 !      - dans usppiv :
 !             . les variables de calcul  (initialisees a 0 par defaut
 !             ou a la valeur donnee dans usiniv)
@@ -113,55 +96,12 @@ subroutine cpphyv &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
-! nphmx            ! e  ! <-- ! nphsmx                                         !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
 ! ibrom            ! te ! <-- ! indicateur de remplissage de romb              !
-!   (nphmx   )     !    !     !                                                !
+!        !    !     !                                                !
 ! izfppp           ! te ! <-- ! numero de zone de la face de bord              !
 ! (nfabor)         !    !     !  pour le module phys. part.                    !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
 !  (ncelet, *)     !    !     !  (at current and previous time steps)          !
@@ -170,10 +110,6 @@ subroutine cpphyv &
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
 ! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
 !  (nfabor, *)     !    !     !                                                !
-! w1...8(ncelet    ! tr ! --- ! tableau de travail                             !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -182,69 +118,47 @@ subroutine cpphyv &
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use numvar
+use optcal
+use cstphy
+use cstnum
+use entsor
+use parall
+use ppppar
+use ppthch
+use coincl
+use cpincl
+use ppincl
+use ppcpfu
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "cstnum.h"
-include "entsor.h"
-include "parall.h"
-include "ppppar.h"
-include "ppthch.h"
-include "coincl.h"
-include "cpincl.h"
-include "ppincl.h"
-include "ppcpfu.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
-integer          nideve , nrdeve , nituse , nrtuse , nphmx
+integer          nvar   , nscal
 
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr), ibrom(nphmx)
+integer          ibrom
 integer          izfppp(nfabor)
-integer          idevel(nideve), ituser(nituse), ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,*), coefb(nfabor,*)
 
-double precision f3max(ncelet)
-
-double precision w1(ncelet),w2(ncelet),w3(ncelet),w4(ncelet)
-double precision w5(ncelet),w6(ncelet),w7(ncelet),w8(ncelet)
-double precision w9(ncelet),w10(ncelet)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
-
 ! Local variables
 
-integer          idebia, idebra
-integer          ntbcpi, icpwi, ntbcpr, icpwr
-integer          ntbmci, imcwi, ntbmcr, imcwr
-integer          ntbwoi, iwori, ntbwor, iworr
-integer          ifinia, ifinra
-integer          iel, icha, icla, iphas, ipcrom, ipcro2
+integer          ntbcpi, ntbcpr
+integer          ntbmci, ntbmcr
+integer          ntbwoi, ntbwor
+integer          iel, icha, icla, ipcrom, ipcro2
 integer          izone, ifac
 integer          ipbrom, ipcx2c, iromf , ioxy
 
@@ -252,6 +166,12 @@ double precision x1sro1, x2sro2, srrom1, uns1pw
 double precision x2tot, wmolme, unsro1
 double precision ff4min,ff4max
 
+double precision, allocatable, dimension(:) :: f3max
+double precision, allocatable, dimension(:) :: w1, w2, w3
+double precision, allocatable, dimension(:) :: w4, w5, w6
+double precision, allocatable, dimension(:) :: w7, w8, w9
+double precision, allocatable, dimension(:) :: w10
+
 integer       ipass
 data          ipass /0/
 save          ipass
@@ -267,10 +187,15 @@ ipass = ipass + 1
 ! 1. INITIALISATIONS A CONSERVER
 !===============================================================================
 
+! Allocate work arrays
+allocate(f3max(ncelet))
+allocate(w1(ncelet), w2(ncelet), w3(ncelet))
+allocate(w4(ncelet), w5(ncelet), w6(ncelet))
+allocate(w7(ncelet), w8(ncelet), w9(ncelet))
+allocate(w10(ncelet))
+
 ! --- Initialisation memoire
 
-idebia = idbia0
-idebra = idbra0
 
 ! --- Initialisation des tableaux de travail
 
@@ -410,9 +335,6 @@ do iel = 1, ncel
   w8(iel) = (rtp(iel,isca(ihm))+w8(iel))/ ( 1.d0+w1(iel) )
 enddo
 
-! --- Gestion memoire
-!     Autres tableaux
-
 ! ------ Macro tableau d'entiers TBCPI : NTBCPI
 !        Macro tableau de reels  TBCPR : NTBCPR
 !        Macro tableau d'entiers TBMCI : NTBMCI
@@ -430,22 +352,9 @@ ntbmcr = 2*ncharb + 8
 ntbwoi = 1
 ntbwor = 4
 
-call memcp1                                                       &
-!==========
- ( idebia , idebra ,                                              &
-   nvar   , ncelet , ncel   , nfac   , nfabor ,                   &
-   ntbcpi , icpwi  ,                                              &
-   ntbcpr , icpwr  ,                                              &
-   ntbmci , imcwi  ,                                              &
-   ntbmcr , imcwr  ,                                              &
-   ntbwoi , iwori  ,                                              &
-   ntbwor , iworr  ,                                              &
-   ifinia , ifinra )
-
 call cpphy1                                                       &
 !==========
- ( ifinia , ifinra ,                                              &
-   ncelet , ncel   ,                                              &
+ ( ncelet , ncel   ,                                              &
    ntbcpi , ntbcpr , ntbmci , ntbmcr , ntbwoi , ntbwor ,          &
    w2     , w3     , w4     , w5     , w6    ,                    &
 !         F1M      F2M      F3M      F4M      F5M
@@ -453,11 +362,8 @@ call cpphy1                                                       &
 !         F6M      F7M      F4P2M
    w8     ,                                                       &
 !         ENTH
-   rtp    , propce  , propce(1,iromf) ,                           &
+   rtp    , propce  , propce(1,iromf) )
 !                          ---------------- (masse vol. gaz)
-   ia(icpwi) , ra(icpwr) ,                                        &
-   ia(imcwi) , ra(imcwr) ,                                        &
-   ia(iwori) , ra(iworr)  )
 
 !===============================================================================
 ! 4. CALCUL DES PROPRIETES PHYSIQUES DE LA PHASE DISPERSEE
@@ -500,10 +406,9 @@ enddo
 !       a partir du premier passage si on est en suite de calcul et
 !         qu'on a relu la masse volumique dans le fichier suite.
 
-iphas = 1
-ipcrom = ipproc(irom(iphas))
+ipcrom = ipproc(irom)
 
-if (ipass.gt.1.or.(isuite.eq.1.and.initro(iphas).eq.1)) then
+if (ipass.gt.1.or.(isuite.eq.1.and.initro.eq.1)) then
   srrom1 = srrom
 else
   srrom1 = 0.d0
@@ -530,10 +435,9 @@ enddo
 !                      ----------------
 !===============================================================================
 
-iphas = 1
-ibrom(iphas) = 1
-ipbrom = ipprob(irom(iphas))
-ipcrom = ipproc(irom(iphas))
+ibrom = 1
+ipbrom = ipprob(irom)
+ipcrom = ipproc(irom)
 
 ! ---> Masse volumique au bord pour toutes les facettes
 !      Les facettes d'entree seront recalculees.
@@ -567,7 +471,7 @@ if ( ipass.gt.1 .or. isuite.eq.1 ) then
                  +wmole(ih2o)*oxyh2o(ioxy)                        &
                  +wmole(ico2)*oxyco2(ioxy) )
 
-        unsro1 = (wmolme*rr*timpat(izone)) / p0(iphas)
+        unsro1 = (wmolme*rr*timpat(izone)) / p0
         x1sro1 = (1.d0-x2tot) * unsro1
         propfb(ifac,ipbrom) = 1.d0 / (x1sro1+x2sro2)
       endif
@@ -576,6 +480,13 @@ if ( ipass.gt.1 .or. isuite.eq.1 ) then
   enddo
 endif
 
+! Free memory
+deallocate(f3max)
+deallocate(w1, w2, w3)
+deallocate(w4, w5, w6)
+deallocate(w7, w8, w9)
+deallocate(w10)
+
 !----
 ! FIN
 !----
