@@ -2,31 +2,26 @@
 
 !VERS
 
-
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
+
 ! Purpose:
 ! -------
 
@@ -57,7 +52,7 @@
 subroutine usipph &
 !================
 
- ( nphmax, nphas , iihmpu, nfecra , iturb , icp , iverif )
+ ( iihmpu, nfecra , iturb , icp , iverif )
 
 
 !===============================================================================
@@ -71,13 +66,11 @@ subroutine usipph &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! nphmax           ! i  ! <-- ! maximum number of phases                       !
-! nphas            ! i  ! <-- ! number of active phases                        !
 ! iihmpu           ! i  ! <-- ! indicates if the XML file from the GUI is      !
 !                  !    !     ! used (1: yes, 0: no)                           !
 ! nfecra           ! i  ! <-- ! Fortran unit number for standard output        !
-! iturb(nphmax)    ! ia ! <-> ! turbulence model                               !
-! icp(nphmax)      ! ia ! <-> ! flag for uniform Cp or not                     !
+! iturb            ! ia ! <-> ! turbulence model                               !
+! icp              ! ia ! <-> ! flag for uniform Cp or not                     !
 ! iverif           ! i  ! <-- ! flag for elementary tests                      !
 !__________________!____!_____!________________________________________________!
 
@@ -86,28 +79,25 @@ subroutine usipph &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+! No module should appear here
+
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-
-! No common should appear here
-
-
-!===============================================================================
-
 ! Arguments
 
-integer nphmax, nphas, iihmpu, nfecra
-integer iturb(nphmax), icp(nphmax)
+integer iihmpu, nfecra
+integer iturb, icp
 integer iverif
 
 ! Local variables
 
-integer iphas
-
 !===============================================================================
 
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
@@ -183,19 +173,19 @@ endif
 !      41...LES (Dynamic)
 !      42...LES (WALE)
 !      50...v2f (phi-model)
+!      51...v2f (BL-v2/k)
 !      60...k-omega SST
+!      70...Spalart Allmaras
 !  For 10, contact the development team before use
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-iturb(iphas) = 20
+iturb = 20
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
 
 ! --- Variable specific heat (ICP=1) or not (ICP=0)
-!       for each phase IPHAS
 
 !     Should be set only if specific physics (coal, combustion, electric arcs)
 !       ARE NOT activated.
@@ -207,12 +197,11 @@ iturb(iphas) = 20
 
 !     Caution:    complete usphyv with the law defining Cp
 !     =========   if and only if variable Cp has been selected here
-!                 (with icp(iphas)=1)
+!                 (with icp=1)
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-icp(iphas) = 0
+icp = 0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -257,18 +246,18 @@ subroutine usinsc &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+
+! No module should appear here
+
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-
-! No common should appear here
-
-
-!===============================================================================
-
 ! Arguments
 
 integer iihmpu, nfecra
@@ -413,18 +402,18 @@ subroutine usipsc &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+
+! No module should appear here
+
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-
-! No common should appear here
-
-
-!===============================================================================
-
 ! Arguments
 
 integer nscmax, nscaus, iihmpu, nfecra
@@ -508,7 +497,7 @@ endif
 !       So, if we set iscavr(j) = k, we must have
 !       0 < j < nscaus+1, 0< k < nscaus+1 and j different from k.
 
-!     For example for user scalar 3 to be the variance of user scalar 3,
+!     For example for user scalar 3 to be the variance of user scalar 2,
 !       we set:
 !       iscavr(3) = 2
 !       with nscaus at least equal to 3.
@@ -588,10 +577,11 @@ end subroutine
 subroutine usipgl &
 !================
 
- ( nphmax, nesmax,                                                &
+ ( nesmax,                                                        &
    iespre, iesder, iescor, iestot,                                &
-   nphas , iihmpu, nfecra,                                        &
-   idtvar, ipucou, iphydr, ialgce , iescal , iverif )
+   iihmpu, nfecra,                                                &
+   idtvar, ipucou, iphydr, ialgce , iescal , iverif ,             &
+   icwfps, cwfthr )
 
 
 !===============================================================================
@@ -605,13 +595,11 @@ subroutine usipgl &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! nphmax           ! i  ! <-- ! maximum number of phases                       !
 ! nesmax           ! i  ! <-- ! maximum number of error estimators per phase   !
 ! iespre           ! i  ! <-- ! number of the prediction error estimator       !
 ! iesder           ! i  ! <-- ! number of the derivative error estimator       !
 ! iescor           ! i  ! <-- ! number of the correction error estimator       !
 ! iestot           ! i  ! <-- ! number of the total error estimator            !
-! nphas            ! i  ! <-- ! number of active phases                        !
 ! iihmpu           ! i  ! <-- ! indicates if the XML file from the GUI is      !
 !                  !    !     ! used (1: yes, 0: no)                           !
 ! nfecra           ! i  ! <-- ! Fortran unit number for standard output        !
@@ -622,9 +610,11 @@ subroutine usipgl &
 !                  !    !     ! head-loss terms                                !
 ! ialgce           ! i  ! <-- ! option for the method of calculation of        !
 !                  !    !     !  cell centers                                  !
-! iescal           ! ia ! <-- ! flag for activation of error estimators for    !
-!  (nesmax,nphmax) !    !     ! Navier-Stokes                                  !
+! iescal(nesmax)   ! ia ! <-- ! flag for activation of error estimators for    !
+!                  !    !     ! Navier-Stokes                                  !
 ! iverif           ! i  ! <-- ! flag for elementary tests                      !
+! cwfthr           ! i  ! <-- ! Treshold angle to cut warped faces (do not     !
+!                  !    !     !  cut warped faces if value is negative)        !
 !__________________!____!_____!________________________________________________!
 
 !     Type: i (integer), r (real), s (string), a (array), l (logical),
@@ -632,31 +622,31 @@ subroutine usipgl &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+
+! No module should appear here
+
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-
-! No common should appear here
-
-
-!===============================================================================
-
 ! Arguments
 
-integer nphmax, nesmax
+integer nesmax
 integer iespre, iesder, iescor, iestot
-integer nphas , iihmpu, nfecra
-integer idtvar, ipucou, iphydr
-integer iescal(nesmax,nphmax)
-integer iverif
+integer iihmpu, nfecra
+integer idtvar, ipucou, iphydr, ialgce
+integer iescal(nesmax)
+integer iverif, icwfps
+
+double precision cwfthr
 
 ! Local variables
 
-integer iphas, ialgce
-
 !===============================================================================
 
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
@@ -763,11 +753,25 @@ iphydr = 0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
 !       div(rho u) -Gamma
-iescal(iescor,iphas) = 0
+iescal(iescor) = 0
 !       resolution precision for the momentum
-iescal(iestot,iphas) = 0
+iescal(iestot) = 0
+
+! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
+
+
+! --- Triangulate warped faces:
+!       If cwfthr is positive, faces whose warping angle are greater than
+!         the given value (in degrees) are subdivided into triangles;
+!       if cwfthr negative, faces are not subdivided.
+!       If icwfps = 1, additional postprocessing will be activated to
+!         show faces before and after cutting.
+
+! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
+
+icwfps = 0
+cwfthr= -1.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -810,32 +814,32 @@ subroutine usipsu &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use cstnum
+use dimens
+use numvar
+use optcal
+use cstphy
+use entsor
+use mltgrd
+use parall
+use period
+use ihmpre
+use ppppar
+use ppthch
+use ppincl
+use coincl
+use cpincl
+use elincl
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "cstnum.h"
-include "dimens.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "entsor.h"
-include "vector.h"
-include "parall.h"
-include "period.h"
-include "ihmpre.h"
-include "ppppar.h"
-include "ppthch.h"
-include "ppincl.h"
-include "coincl.h"
-include "cpincl.h"
-include "elincl.h"
-
-!===============================================================================
-
 ! Arguments
 
 integer nmodpp
@@ -843,7 +847,7 @@ integer iverif
 
 ! Local variables
 
-integer iphas, iutile, ii, jj, imom
+integer iutile, ii, jj, imom
 
 !===============================================================================
 
@@ -912,12 +916,10 @@ endif
 ! Calculation options (optcal.h)
 ! ==============================
 
-! --- Calculation restart: isuite (= 1) or not (0)
 !     In case of restart, read auxiliary restart file ileaux (= 1) or not (0).
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-isuite = 0
 ileaux = 1
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
@@ -967,24 +969,24 @@ dtref  = 0.01d0
 
 !   On the other hand, if specific physics are NOT activated:
 
-!     If a USER scalar represents the temperature or enthalpy (of phase iphas):
-!       we define the number of this scalar in iscalt(iphas) and
-!       we set iscsth(iscalt(iphas)) = 1 if it is the temperature
-!          or  iscsth(iscalt(iphas)) = 2 if it is the enthalpy.
+!     If a USER scalar represents the temperature or enthalpy:
+!       we define the number of this scalar in iscalt and
+!       we set iscsth(iscalt) = 1 if it is the temperature
+!          or  iscsth(iscalt) = 2 if it is the enthalpy.
 
-!     If no scalar represents the temperature or enthalpy (of phase iphas)
-!       we set iscalt(iphas) = -1
-!       and we do not define iscsth(iscalt(iphas)).
+!     If no scalar represents the temperature or enthalpy
+!       we set iscalt = -1
+!       and we do not define iscsth(iscalt).
 
 
 !     For the radiative module when used without specific physics, if we
 !      have chosen to solve in temperature (that is if
-!      iscsth(iscalt(iphas)) = 1), the fluid temperature is considered to
+!      iscsth(iscalt) = 1), the fluid temperature is considered to
 !      be in degrees KELVIN (be careful for boundary conditions an expression
 !      of physical properties depending on temperature).
 !      Nonetheless, even though it is not recommended, if we wish for the
 !      fluid solver to work with a temperature in degrees Celsius, we must set
-!      iscsth(iscalt(iphas)) = -1.
+!      iscsth(iscalt) = -1.
 !      This choice is a source of user errors. Indeed, the boundary conditions
 !      for the fluid temperature will then be in degrees Celsius, while the
 !      boundary conditions for radiation in usray2 must still be in Kelvin.
@@ -997,18 +999,16 @@ dtref  = 0.01d0
 
 if (nmodpp.eq.0) then
 
-  iphas = 1
-
   ! Number of the scalar representing temperature or enthalpy,
   !   or -1 if there is none.
   ! When the choice is done by the Code_Saturne GUI, the scalar representing
   !   the temperature or enthalpy is always the first.
-  iscalt(iphas) = -1
+  iscalt = -1
 
 ! If there is a temperature or enthalpy variable:
-  if (iscalt(iphas).gt.0) then
+  if (iscalt.gt.0) then
     ! we indicate if it is the temperature (=1) or the enthalpy (=2).
-    iscsth(iscalt(iphas)) = 1
+    iscsth(iscalt) = 1
   endif
 
 endif
@@ -1031,8 +1031,7 @@ iccvfg = 0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-if (itytur(iphas).eq.4) then
+if (itytur.eq.4) then
   ivrtex = 0
 endif
 
@@ -1056,7 +1055,7 @@ endif
 !         blencv(ivar) = 1.0d0 to use a second-order scheme in space for
 !         convection. For temperature or enthalpy in particular, we
 !         may thus choose in this case:
-!          blencv(isca(iscalt(iphas))) = 1.0d0
+!          blencv(isca(iscalt)) = 1.0d0
 
 !       For non-user scalars relative to specific physics (coal, combustion,
 !         electric arcs: see usppmo) implicitly defined by the model,
@@ -1066,11 +1065,9 @@ endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-
-blencv(iu(iphas)) = 1.0d0
-blencv(iv(iphas)) = 1.0d0
-blencv(iw(iphas)) = 1.0d0
+blencv(iu) = 1.0d0
+blencv(iv) = 1.0d0
+blencv(iw) = 1.0d0
 if (nscaus.ge.1) then
   do ii = 1, nscaus
     blencv(isca(ii)) = 1.0d0
@@ -1088,6 +1085,7 @@ endif
 !                            j = 0: conjugate gradient,
 !                            j = 1: Jacobi
 !                            j = 2: bi-CgStab
+!                            j = 3: GMRES
 
 !     nitmax: maximum number of iterations for each unknown ivar
 !     epsilo: relative precision for the solution of the linear system.
@@ -1097,10 +1095,9 @@ endif
 iutile = 0
 if (iutile.eq.1) then
 
-  iphas = 1
-  iresol(iu(iphas)) = 2
-  iresol(iv(iphas)) = 2
-  iresol(iw(iphas)) = 2
+  iresol(iu) = 2
+  iresol(iv) = 2
+  iresol(iw) = 2
   if (nscaus.ge.1) then
     do ii = 1, nscaus
       iresol(isca(ii)) = 2
@@ -1123,8 +1120,12 @@ endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-imgr(ipr(iphas)) = 1
+! mltmmn = 300  ! mean number of cells under which merging takes place
+! mltmgl = 500  ! global number of cells under which merging takes place
+! mltmmr = 1    ! number of active ranks under which no merging is done
+! mltmst = 4    ! number of ranks over which merging takes place
+
+imgr(ipr) = 1
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -1136,14 +1137,14 @@ imgr(ipr(iphas)) = 1
 !     For difficult cases, a stabilization may be obtained by not
 !     reconstructing the convective and diffusive flux for variables
 !     of the turbulence model, that is
-!       in k-epsilon: if (itytur(iphas).eq.2) then
-!          ircflu(ik(iphas))   = 0 and ircflu(iep(iphas))  = 0
-!       in Rij-epsilon: if (itytur(iphas).eq.3) then
-!          ircflu(ir11(iphas)) = 0,    ircflu(ir22(iphas)) = 0,
-!          ircflu(ir33(iphas)) = 0,
-!          ircflu(ir12(iphas)) = 0,    ircflu(ir23(iphas)) = 0,
-!          ircflu(ir23(iphas)) = 0,
-!                                  and ircflu(iep(iphas))  = 0
+!       in k-epsilon: if (itytur.eq.2) then
+!          ircflu(ik)   = 0 and ircflu(iep)  = 0
+!       in Rij-epsilon: if (itytur.eq.3) then
+!          ircflu(ir11) = 0,    ircflu(ir22) = 0,
+!          ircflu(ir33) = 0,
+!          ircflu(ir12) = 0,    ircflu(ir23) = 0,
+!          ircflu(ir23) = 0,
+!                                  and ircflu(iep)  = 0
 !     (note that variable itytur is equal to iturb/10)
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
@@ -1154,10 +1155,9 @@ imgr(ipr(iphas)) = 1
 iutile = 0
 if (iutile.eq.1) then
 
-  iphas = 1
-  if (iturb(iphas).eq.20) then
-    ircflu(ik(iphas))   = 0
-    ircflu(iep(iphas))  = 0
+  if (iturb.eq.20) then
+    ircflu(ik)   = 0
+    ircflu(iep)  = 0
   endif
 
 endif
@@ -1206,7 +1206,7 @@ omegaz = 0.d0
 !                    the calculation is based on a
 !                    reduced pressure P*=Ptot-ro0*g.(x-xref)
 !                    (except in compressible case)
-!       xyzp0(3,.) : coordinates of the reference point for
+!       xyzp0(3)   : coordinates of the reference point for
 !                    the total pressure (where it is equal to p0)
 
 !     In general, it is not necessary to furnish a reference point xyz0.
@@ -1301,23 +1301,19 @@ omegaz = 0.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-
-ro0(iphas)    = 0.235d0
-viscl0(iphas) = 0.84d-6
-cp0(iphas)    = 1219.d0
+ro0    = 0.235d0
+viscl0 = 0.84d-6
+cp0    = 1219.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
-iphas = 1
-
-t0(iphas) = 1000.d0 + 273.15d0
-p0(iphas) = 1.01325d5
+t0 = 1000.d0 + 273.15d0
+p0 = 1.01325d5
 ! We only specify XYZ0 if we explicitely fix Dirichlet conditions
 ! for the pressure.
-! xyzp0(1,iphas) = 0.d0
-! xyzp0(2,iphas) = 0.d0
-! xyzp0(3,iphas) = 0.d0
+! xyzp0(1) = 0.d0
+! xyzp0(2) = 0.d0
+! xyzp0(3) = 0.d0
 
 
 ! --- irovar, ivivar: density and viscosity constant or not ?
@@ -1330,7 +1326,7 @@ p0(iphas) = 1.01325d5
 !       in the uscfx1 user subroutine.
 
 !     When no specific physics module is active, it is necessary to
-!       specify is the density and the molecular viscosity
+!       specify if the density and the molecular viscosity
 !         are constant (irovar=0, ivivar=0)
 !          or variable (irovar=1, ivivar=1)
 
@@ -1342,9 +1338,8 @@ p0(iphas) = 1.01325d5
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
 if (nmodpp.eq.0) then
-  iphas = 1
-  irovar(iphas) = 0
-  ivivar(iphas) = 0
+  irovar = 0
+  ivivar = 0
 endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
@@ -1403,7 +1398,7 @@ endif
 !     When no specific physics has been activated
 !       (coal, combustion, electric arcs) and if a user scalar represents
 !       the temperature or enthalpy:
-!       visls0(iscalt(iphas)) = Lambda/Cp
+!       visls0(iscalt) = Lambda/Cp
 
 !     Here, as an example, we assign to viscl0 the viscosity of the
 !       carrier phase, which is fitting for passive tracers which
@@ -1420,7 +1415,7 @@ if (nscaus.gt.0) then
     ! For scalars which are not variances
     if (iscavr(jj).le.0) then
       ! We define the diffusivity
-      visls0(jj) = viscl0(iphsca(jj))
+      visls0(jj) = viscl0
     endif
   enddo
 
@@ -1434,8 +1429,7 @@ endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-uref(iphas)    = 1.d0
+uref    = 1.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -1448,8 +1442,7 @@ uref(iphas)    = 1.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
-iphas = 1
-almax(iphas) = -grand
+almax = -grand
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -1484,15 +1477,13 @@ if (iutile.eq.1) then
 
   ! First moment: <u>
   imom  = 1
-  iphas = 1
-  idfmom(1,imom) =  iu(iphas)
+  idfmom(1,imom) =  iu
   ntdmom(imom)   =  1000
   ! Second moment: <rho u v>
   imom  = 2
-  iphas = 1
-  idfmom(1,imom) = -irom(iphas)
-  idfmom(2,imom) =  iu(iphas)
-  idfmom(3,imom) =  iv(iphas)
+  idfmom(1,imom) = -irom
+  idfmom(2,imom) =  iu
+  idfmom(3,imom) =  iv
   imoold(imom)   = -1
   ntdmom(imom)   =  10000
 
@@ -1537,29 +1528,28 @@ subroutine usipes &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use cstnum
+use dimens
+use numvar
+use optcal
+use cstphy
+use entsor
+use parall
+use period
+use ihmpre
+use ppppar
+use ppthch
+use ppincl
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "cstnum.h"
-include "dimens.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "entsor.h"
-include "vector.h"
-include "parall.h"
-include "period.h"
-include "ihmpre.h"
-include "ppppar.h"
-include "ppthch.h"
-include "ppincl.h"
-
-!===============================================================================
-
 ! Arguments
 
 integer nmodpp
@@ -1567,7 +1557,7 @@ integer iverif
 
 ! Local variables
 
-integer ii, iphas, ipp, imom, iutile
+integer ii, ipp, imom, iutile
 
 !===============================================================================
 
@@ -1664,79 +1654,25 @@ ntlist = 1
 iutile = 0
 if (iutile.eq.1) then
 
-  iphas = 1
-
   do ii = 1, nvar
     iwarni(ii) = 1
   enddo
 
-  iwarni(ipr(iphas)) = 2
-  iwarni(iu(iphas)) = 2
-  iwarni(iv(iphas)) = 2
-  iwarni(iw(iphas)) = 2
+  iwarni(ipr) = 2
+  iwarni(iu) = 2
+  iwarni(iv) = 2
+  iwarni(iw) = 2
 
 endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
-! --- post-processing output
-
-!     ichrvl: post-processing of the fluid domain (yes 1/no 0)
-!     ichrbo: post-processing of the domain boundary (yes 1/no 0)
-!     ichrsy: post-processing of zones coupled with SYRTHES (yes 1/ no 0)
-!     ichrmd: indicates if the meshes output are:
-!               0: fixed,
-!               1: deformable with constant connectivity,
-!               2: modifyable (may be completely redefined during the
-!                  calculation using the usmpst subroutine).
-!              10: as indmod = 0, with a displacement field
-!              11: as indmod = 1, with a displacement field
-!              11: as indmod = 2, with a displacement field
-
-!     fmtchr: output format, amid
-!               'EnSight Gold', 'MED', or 'CGNS'
-!     optchr: options associated with the output format, separated by
-!             commas, from the following list:
-!               'text'              (text format, for EnSight)
-!               'binary'            (binary format, default choice)
-!               'big_endian'        (forces binary EnSight output to
-!                                   'big-endian' mode)
-!               'discard_polygons'  (ignore polygon-type faces)
-!               'discard_polyhedra' (ignore polyhedron-type cells)
-!               'divide_polygons'   (subdivides polygon-type faces)
-!               'divide_polyhedra'  (subdivides polyhedron-type cells)
-!               'split_tensors'     (writes tensors as separate scalars)
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
-
-ichrvl = 1
-ichrbo = 0
-ichrsy = 0
-
-ichrmd = 0
-
-fmtchr = 'EnSight Gold'
-optchr = 'binary'
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
-
-
-! --- chronological output step
-!       (-1: only one valua at calculation end)
-!       (strictly positive valeu: output periodicity)
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
-
-ntchr = -1
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
-
-
 ! --- history output step
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
 nthist = 1
+frhist = -1.d0
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
 
@@ -1747,6 +1683,8 @@ nthist = 1
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
 ncapt  = 4
+tplfmt = 1 ! time plot format (1: .dat, 2: .csv, 3: both)
+
 xyzcap(1,1) = 0.30d0
 xyzcap(2,1) = 0.15d0
 xyzcap(3,1) = 0.01d0
@@ -1787,11 +1725,8 @@ xyzcap(3,4) = 0.01d0
 
 ! Current dynamic variables
 
-! Examples for phase 1
-iphas = 1
-
 ! pressure variable
-ipp = ipprtp(ipr   (iphas))
+ipp = ipprtp(ipr   )
 nomvar(ipp)   = 'Pressure'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 1
@@ -1801,7 +1736,7 @@ if (icorio.eq.1) then
 endif
 
 ! variable v1x
-ipp = ipprtp(iu    (iphas))
+ipp = ipprtp(iu    )
 nomvar(ipp)   = 'VelocityX'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 1
@@ -1811,7 +1746,7 @@ if (icorio.eq.1) then
 endif
 
 ! v1y variable
-ipp = ipprtp(iv    (iphas))
+ipp = ipprtp(iv    )
 nomvar(ipp)   = 'VelocityY'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 1
@@ -1821,7 +1756,7 @@ if (icorio.eq.1) then
 endif
 
 ! v1z variable
-ipp = ipprtp(iw    (iphas))
+ipp = ipprtp(iw    )
 nomvar(ipp)   = 'VelocityZ'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 1
@@ -1830,119 +1765,158 @@ if (icorio.eq.1) then
   nomvar(ipp)   = 'Rel VelocityZ'
 endif
 
-if (itytur(iphas).eq.2) then
+if (itytur.eq.2) then
 
   ! turbulent kinetic energy
-  ipp = ipprtp(ik    (iphas))
+  ipp = ipprtp(ik    )
   nomvar(ipp)   = 'Turb Kinetic Energy'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! turbulent dissipation
-  ipp = ipprtp(iep   (iphas))
+  ipp = ipprtp(iep   )
   nomvar(ipp)   = 'Turb Dissipation'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
-elseif (itytur(iphas).eq.3) then
+elseif (itytur.eq.3) then
 
   ! Reynolds stresses
-  ipp = ipprtp(ir11  (iphas))
+  ipp = ipprtp(ir11  )
   nomvar(ipp)   = 'R11'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! Reynolds stresses
-  ipp = ipprtp(ir22  (iphas))
+  ipp = ipprtp(ir22  )
   nomvar(ipp)   = 'R22'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! Reynolds stresses
-  ipp = ipprtp(ir33  (iphas))
+  ipp = ipprtp(ir33  )
   nomvar(ipp)   = 'R33'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! Reynolds stresses
-  ipp = ipprtp(ir12  (iphas))
+  ipp = ipprtp(ir12  )
   nomvar(ipp)   = 'R12'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! Reynolds stresses
-  ipp = ipprtp(ir13  (iphas))
+  ipp = ipprtp(ir13  )
   nomvar(ipp)   = 'R13'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! Reynolds stresses
-  ipp = ipprtp(ir23  (iphas))
+  ipp = ipprtp(ir23  )
   nomvar(ipp)   = 'R23'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! turbulent dissipation
-  ipp = ipprtp(iep   (iphas))
+  ipp = ipprtp(iep   )
   nomvar(ipp)   = 'Turb Dissipation'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
-elseif (iturb(iphas).eq.50) then
+elseif (iturb.eq.50) then
 
   ! turbulent kinetic energy
-  ipp = ipprtp(ik    (iphas))
+  ipp = ipprtp(ik    )
   nomvar(ipp)   = 'Turb Kinetic Energy'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! turbulent dissipation
-  ipp = ipprtp(iep   (iphas))
+  ipp = ipprtp(iep   )
   nomvar(ipp)   = 'Turb Dissipation'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! phi
-  ipp = ipprtp(iphi  (iphas))
+  ipp = ipprtp(iphi  )
   nomvar(ipp)   = 'Phi'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! f_bar
-  ipp = ipprtp(ifb   (iphas))
+  ipp = ipprtp(ifb   )
   nomvar(ipp)   = 'f_bar'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
-elseif (iturb(iphas).eq.60) then
+elseif (iturb.eq.51) then
 
   ! turbulent kinetic energy
-  ipp = ipprtp(ik    (iphas))
+  ipp = ipprtp(ik    )
+  nomvar(ipp)   = 'Turb Kinetic Energy'
+  ichrvr(ipp)   = 1
+  ilisvr(ipp)   = 1
+  ihisvr(ipp,1) = -1
+
+  ! turbulent dissipation
+  ipp = ipprtp(iep   )
+  nomvar(ipp)   = 'Turb Dissipation'
+  ichrvr(ipp)   = 1
+  ilisvr(ipp)   = 1
+  ihisvr(ipp,1) = -1
+
+  ! phi
+  ipp = ipprtp(iphi  )
+  nomvar(ipp)   = 'Phi'
+  ichrvr(ipp)   = 1
+  ilisvr(ipp)   = 1
+  ihisvr(ipp,1) = -1
+
+  ! alpha
+  ipp = ipprtp(ial   )
+  nomvar(ipp)   = 'Alpha'
+  ichrvr(ipp)   = 1
+  ilisvr(ipp)   = 1
+  ihisvr(ipp,1) = -1
+
+elseif (iturb.eq.60) then
+
+  ! turbulent kinetic energy
+  ipp = ipprtp(ik    )
   nomvar(ipp)   = 'Turb Kinetic Energy'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
   ! omega
-  ipp = ipprtp(iomg  (iphas))
+  ipp = ipprtp(iomg  )
   nomvar(ipp)   = 'Omega'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
   ihisvr(ipp,1) = -1
 
+elseif (iturb.eq.70) then
+
+  ! Spalart-Allmaras variable (viscosity-like)
+  ipp = ipprtp(inusa )
+  nomvar(ipp)   = 'NuTilda'
+  ichrvr(ipp)   = 1
+  ilisvr(ipp)   = 1
+  ihisvr(ipp,1) = -1
+
 endif
 
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
@@ -1979,21 +1953,19 @@ endif
 
 ! Other variables
 
-iphas = 1
-
 ! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
 
 ! Density variable (output for post-processing only if variable or
 !                   in the case of specific physics)
-ipp = ipppro(ipproc(irom  (iphas)))
+ipp = ipppro(ipproc(irom  ))
 nomvar(ipp)   = 'Density'
-ichrvr(ipp)   = max(irovar(iphas),nmodpp)
+ichrvr(ipp)   = max(irovar,nmodpp)
 ilisvr(ipp)   = 1
 ihisvr(ipp,1) = -1
 
 ! specific heat
-if (icp   (iphas).gt.0) then
-  ipp = ipppro(ipproc(icp   (iphas)))
+if (icp   .gt.0) then
+  ipp = ipppro(ipproc(icp   ))
   nomvar(ipp)   = 'Specific Heat'
   ichrvr(ipp)   = 0
   ilisvr(ipp)   = 0
@@ -2001,28 +1973,28 @@ if (icp   (iphas).gt.0) then
 endif
 
 ! laminar viscosity
-ipp = ipppro(ipproc(iviscl(iphas)))
+ipp = ipppro(ipproc(iviscl))
 nomvar(ipp)   = 'Laminar Viscosity'
 ichrvr(ipp)   = 0
 ilisvr(ipp)   = 0
 ihisvr(ipp,1) = 0
 
 ! turbulent viscosity
-ipp = ipppro(ipproc(ivisct(iphas)))
+ipp = ipppro(ipproc(ivisct))
 nomvar(ipp)   = 'Turb Viscosity'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 1
 ihisvr(ipp,1) = -1
 
 ! Courant number
-ipp = ipppro(ipproc(icour(iphas)))
+ipp = ipppro(ipproc(icour))
 nomvar(ipp)   = 'CFL'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 0
 ihisvr(ipp,1) = -1
 
 ! Fourier number
-ipp = ipppro(ipproc(ifour(iphas)))
+ipp = ipppro(ipproc(ifour))
 nomvar(ipp)   = 'Fourier Number'
 ichrvr(ipp)   = 1
 ilisvr(ipp)   = 0
@@ -2030,8 +2002,8 @@ ihisvr(ipp,1) = -1
 
 ! 'csmago' variable for dynamic L.E.S. models
 !    (square of the Samgorinsky "constant")
-if (ismago(iphas).gt.0) then
-  ipp = ipppro(ipproc(ismago(iphas)))
+if (ismago.gt.0) then
+  ipp = ipppro(ipproc(ismago))
   nomvar(ipp)   = 'Csdyn2'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
@@ -2050,7 +2022,7 @@ endif
 
 ! total pressure (not defined in compressible case)
 if (ippmod(icompf).lt.0) then
-  ipp = ipppro(ipproc(iprtot(iphas)))
+  ipp = ipppro(ipproc(iprtot))
   nomvar(ipp)   = 'Total Pressure'
   ichrvr(ipp)   = 1
   ilisvr(ipp)   = 1
@@ -2092,135 +2064,5 @@ ihisvr(ipp,1) = -1
 
 
 
-return
-end subroutine
-
-
-!===============================================================================
-
-
-subroutine ustbtr &
-!================
-
- ( ncel   , ncelet , nfac   , nfabor , nnod   ,                   &
-   longia , longra ,                                              &
-   nideve , nituse , nrdeve , nrtuse )
-
-!===============================================================================
-! Purpose:
-! -------
-
-! User subroutine to define the sizes of macro-arrays ia and ra,
-!   of user arrays ituser and rtuser,
-!   of developper arrays idevel and rdevel.
-
-!-------------------------------------------------------------------------------
-! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! ncel             ! i  ! <-- ! number of cells                                !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! longia           ! i  ! --> ! size of array ia                               !
-! longra           ! i  ! --> ! size of array ra                               !
-! nideve           ! i  ! --> ! size of array idevel                           !
-! nituse           ! i  ! --> ! size of array ituser                           !
-! nrdeve           ! i  ! --> ! size of array rdevel                           !
-! nrtuse           ! i  ! --> ! size of array rtuser                           !
-!__________________!____!_____!________________________________________________!
-
-!     Type: i (integer), r (real), s (string), a (array), l (logical),
-!           and composite types (ex: ra real array)
-!     mode: <-- input, --> output, <-> modifies data, --- work array
-!===============================================================================
-
-implicit none
-
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-!===============================================================================
-
-! Arguments
-
-integer          ncel  , ncelet, nfac  , nfabor, nnod
-integer          longia, longra
-integer          nideve, nituse, nrdeve, nrtuse
-
-!===============================================================================
-
-! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
-!===============================================================================
-! 0.  This test allows the user to ensure that the version of this subroutine
-!       used is that from his case definition, and not that from the library.
-!     If a file from the GUI is used, this subroutine may not be mandatory,
-!       thus the default (library reference) version returns immediately.
-
-if (1.eq.1) return
-
-!===============================================================================
-! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_END
-
-!===============================================================================
-! 1. Size of macro arrays ia and ra:
-
-!  The user may need to modify the size of integer and real work
-!    arrays here: longia and longra respectively.
-
-!  The number of integers 'longia' and the number of reals 'longra' depend
-!    on calculation options, on the element type and mesh characteristics
-!    (2d, 3d, hybrid, non-conforming, ...) and on the number of variables.
-!  In k-epsilon, if we note 'ncel' the local number of cells in the mesh,
-!    we ay usually use the following coarse overestimation:
-!    longia = 45*ncel and longra = 220*ncel. In Rij-epsilon, an additional
-!    20% may be applied.
-!  These values are relatively high so as to account for 2D meshes which
-!    have many boundary faces. A more precise but complex formula would be
-!    necessary. For large 3D cases, a more precise estimation is given by:
-!    longia = 25*ncel  and longra = 120*ncel.
-
-!  If longia and longra are left at 0, then these values are estimated
-!    and set automatically.
-
-!===============================================================================
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
-
-! Size of main integer work array 'ia'
-
-longia = 0
-
-! Size of main real work array 'ra'
-
-longra = 0
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
-
-!===============================================================================
-! 2. Size of macro arrays ituser and rtuser:
-!===============================================================================
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_START
-
-! Size user-reserved integer array 'ituser'
-
-nituse = 0
-
-! Size user-reserved real array 'rtuser'
-
-nrtuse = 0
-
-! EXAMPLE_CODE_TO_BE_ADAPTED_BY_THE_USER_END
-
-
-!----
-! Formats
-!----
-
-
 return
 end subroutine
